<?php
defined( 'ABSPATH' ) or die( 'No direct script access allowed' );
/*
* Plugin Name: MonLabo
* Plugin URI: http://www.monlabo.org
* Description:  Simplifier la gestion d'un site web d'une unité de recherche
* Version: 2.8
* Author: Hervé SUAUDEAU (créateur) et Delphine RIDER (co-auteure)
* Text Domain: MonLabo
*/
function get_version() { return '2.8'; }

///////////////////////////////////////////////////////////////////////////////////////////
//					   PLUGIN CLASS DEFINITIONS
///////////////////////////////////////////////////////////////////////////////////////////

require_once( dirname( __FILE__ ) . '/includes/MonLabo-lib.php' );
require_once( dirname( __FILE__ ) . '/includes/MonLabo-persons.php' );
require_once( dirname( __FILE__ ) . '/includes/MonLabo-shortcodes-publications.php' );
require_once( dirname( __FILE__ ) . '/includes/MonLabo-shortcodes.php' );
require_once( dirname( __FILE__ ) . '/includes/MonLabo-db.php' );
require_once( dirname( __FILE__ ) . '/includes/constants.php' );
require_once( dirname( __FILE__ ) . '/includes/MonLabo-access-data.php' );
require_once( dirname( __FILE__ ) . '/includes/MonLabo-generate-HTML.php' );


/* main
*******/
if ( !class_exists( 'MonLabo' ) ) {
	class MonLabo {
		function  __construct() {
			add_action( 'init', array( &$this, 'MonLabo_init' ) );
			if ( is_admin() ) {
				require_once( dirname( __file__ ).'/admin/MonLabo-admin.php' );
			}
		}

		//hook into WP's admin_init action hook
		public function MonLabo_init()
		{
			$options = get_option( 'MonLabo_settings_group0' );
			if ( isset( $options['MonLabo_uses_members_and_groups'] ) && ( 1 === intval( $options['MonLabo_uses_members_and_groups'] ) ) ) {
				add_shortcode( 'members_list', array( 'MonLabo_shortcodes', 'members_list' ) );
				add_shortcode( 'members_table', array( 'MonLabo_shortcodes', 'members_table' ) );
				add_shortcode( 'members_chart', array( 'MonLabo_shortcodes', 'members_chart' ) );
				add_shortcode( 'alumni_list', array( 'MonLabo_shortcodes', 'alumni_list' ) );
				add_shortcode( 'alumni_table', array( 'MonLabo_shortcodes', 'alumni_table' ) );
				add_shortcode( 'alumni_chart', array( 'MonLabo_shortcodes', 'alumni_chart' ) );
				add_shortcode( 'teams_list', array( 'MonLabo_shortcodes', 'teams_list' ) );
				add_shortcode( 'perso_panel', array( 'MonLabo_shortcodes', 'perso_panel' ) );
				add_shortcode( 'team_panel', array( 'MonLabo_shortcodes', 'team_panel' ) );

				//For development (not documented )
				add_shortcode( 'dev_team_name', array( 'MonLabo_shortcodes', 'dev_team_name' ) );
				add_shortcode( 'dev_team_logo', array( 'MonLabo_shortcodes', 'dev_team_logo' ) );

				//For retrocompatibility:
				add_shortcode( 'alumni', array( 'MonLabo_shortcodes', 'alumni' ) ); //For retrocompatibility - TO BE DELETED
				add_shortcode( 'perso_panel_automatic', array( 'MonLabo_shortcodes', 'perso_panel' ) );
				add_shortcode( 'members_list_automatic', array( 'MonLabo_shortcodes', 'members_list' ) );
				add_shortcode( 'perso_publications_automatic', array( 'MonLabo_shortcodes', 'publications_list' ) );
				add_shortcode( 'get_members_list', array( 'MonLabo_shortcodes', 'members_list' ) );

			}

			// Shortcodes for publications
			add_shortcode( 'publications_list', array( 'MonLabo_shortcodes_publications', 'publications_list' ) );
			add_shortcode( 'publications_automatic', array( 'MonLabo_shortcodes_publications', 'publications_list' ) ); //For retrocompatibility
			add_shortcode( 'custom_publications_list', array( 'MonLabo_shortcodes_publications', 'custom_publications_list' ) );
			add_shortcode( 'get_publications', array( 'MonLabo_shortcodes_publications', 'custom_publications_list' ) ); //For retrocompatibility

			//For translation
			load_plugin_textdomain( 'MonLabo', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );

			$options = get_option( 'MonLabo_settings_group2' );
			$color1 = $options['MonLabo_foreground_color'];
			$color2 = $options['MonLabo_address_color'];
			$address_font_size = $options['MonLabo_address_size'];
			$address_block_width = $options['MonLabo_address_block_width'];
			$perso_panel_width = $options['MonLabo_perso_panel_width'];
			$img_arrondi = $options['MonLabo_img_arrondi'];
			$name_size = $options['MonLabo_name_size'];

			wp_enqueue_style( 'MonLabo', plugin_dir_url( __FILE__ ).'MonLabo.css', array(), get_version() );
			$MonLabo_access_data = New MonLabo_access_data();
			//TODO: Retirer les commentaires et voir pourquoi cela plante
			/*$teams = $MonLabo_access_data->get_teams_information();
			$teams_id = array();
			$teams_color = '';
			if ( !empty( $teams ) ){
			  foreach ( $teams as $team ) {
				if ( isset( $team->color ) and ( $team->color! = '' ) ) {
				  $teams_color. = ".MonLabo-persons-chart td .team_$team->id { color:'$team->color'; }";
				}
			  }
		  }*/
			wp_add_inline_style( 'MonLabo', '
.MonLabo-persons-list {
	color: '.$color1.';
}

.MonLabo-persons-list a:visited {
	color: '.$color1.';
}

.MonLabo-persons-list ul li img {
	border-color: '.$color1.';
}

.MonLabo-persons-list ul li a:hover img {
	border-color: '.$color1.';
}

.MonLaboUser a,
.MonLaboUser a:hover,
.MonLaboUser a:visited {
	color: '.$color1.' !important;
}

a.MonLaboLink,
a.MonLaboLink:hover,
a.MonLaboLink:visited {
	color: '.$color1.' !important;
}

.publi_parisdescartes a {
	color: '.$color1.' !important;
}

.bandeau-personnel {
	width: '.$perso_panel_width.';
}

.bandeau-personnel .adresse {
	color: '.$color2.';
	width: '.$address_block_width.';
}

.bandeau-personnel .adresse p {
	font-size: '.$address_font_size.';
}

.bandeau-personnel h1 {
	font-size: '.$name_size.';
}

.img-arrondi  {
	border-radius: '.$img_arrondi.';
}
				'
				/*.$teams_color*/
				.$options['MonLabo_custom_css'] );

			//On ajoute un bouton éventuel sur la barre d'admin
			if ( is_admin_bar_showing() ) {
				require_once( dirname( __file__ ).'/admin/MonLabo-admin.php' );
				add_action( 'admin_bar_menu', 'MonLabo_admin_custom_toolbar_user_link', 999 );
			}
		}
	}
}


/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-plugin-name-activator.php
 */
function activate_MonLabo() {
	$MonLabo_DB = New MonLabo_db();
	$options0 = get_option( 'MonLabo_settings_group0' );

	if(($MonLabo_DB->check_tables_exist()) or ($MonLabo_DB->check_tables_exist("{$wpdb->prefix}MonLabo_persons"))) {
		if ( ( !isset( $options0 ) )
			or ( !isset( $options0['MonLabo_activated_version'] ) )
			or ( $options0['MonLabo_activated_version'] != get_version() )
		) {
			$MonLabo_DB->migrate();
		}
	} else {
		$MonLabo_DB->create_tables();
		$MonLabo_DB->fill_tables_with_default_values_if_empty();
		$MonLabo_DB->fill_options_with_default_values_if_empty();
	}

	//Mise à jour de la version activée
	$options0['MonLabo_activated_version'] = get_version();
	update_option( 'MonLabo_settings_group0', $options0 );
}

//Deactivate the plugin
function deactivate_MonLabo()  { /*Do nothing*/ }

//Check if the database is old
function MonLabo_update_db_check() {
	$options0 = get_option( 'MonLabo_settings_group0' );
	if ( ( !isset( $options0 ) )
		or ( !isset( $options0['MonLabo_activated_version'] ) )
		or ( $options0['MonLabo_activated_version'] != get_version() )
	) {
        activate_MonLabo();
    }
}

///////////////////////////////////////////////////////////////////////////////////////////
//					   MAIN CODE
///////////////////////////////////////////////////////////////////////////////////////////
if ( class_exists( 'MonLabo' ) ) {

	// Installation hooks
	register_activation_hook	( __FILE__, 'activate_MonLabo' );
	register_deactivation_hook  ( __FILE__, 'deactivate_MonLabo' );

	// register_activation_hook() is not called when a plugin is updated. Thus
	// check if database is updtaed
	add_action( 'plugins_loaded', 'MonLabo_update_db_check' );

	// instantiate the plugin class
	$laboPlugin = new MonLabo();

	// Add a link to the settings page onto the plugin page
	if ( isset( $laboPlugin ) ) {
		// Add the settings link to the plugins page
		function plugin_settings_link( $links ) {
			$settings_link = '<a href="'.admin_url( 'admin.php?page=MonLabo' ).'" title="' . __( 'Ouvre la page de configuration pour cette extension', 'MonLabo' ) . '">'.__( 'Configuration', 'MonLabo' ).'</a>';
			array_unshift( $links, $settings_link );
			return $links;
		}

		$plugin = plugin_basename( __FILE__ );
		add_filter( "plugin_action_links_$plugin", 'plugin_settings_link' );
	}
}
