<?php

defined( 'ABSPATH' ) or die('No direct script access allowed' );

///////////////////////////////////////////////////////////////////////
// GESTION DES VARIABLES PASSEES ENTRE PAGES
///////////////////////////////////////////////////////////////////////

//Format and secure string (or table of string) that can be given via POST method
function getPOSTstring( $varName ) {
	if ( isset( $_POST[$varName] ) ) {
		if ( is_array( $_POST[$varName] ) ) {
			//If table of string
			$retval = array();
			if ( !empty( $_POST[$varName] ) ) {
				foreach ( $_POST[$varName] as $key => $value ) {
					$retval[$key] = str_replace( "'", "’", htmlspecialchars( sanitize_text_field( $value ) ) );
				}
			}
			return $retval;
		} else {
			//If simple string
			return str_replace( "'", "’", htmlspecialchars( sanitize_text_field( $_POST[$varName] ) ) );
		}
	} else {
		trigger_error( "\nERROR: String $varName n'est pas passée par un POST.\n", E_USER_WARNING );
		return NULL;
	}
}

//Format and secure number that can be given via POST method
function getPOSTnumber( $varName ) {
  if ( isset( $_POST[$varName] ) and ctype_digit( (string) $_POST[$varName] ) ) {
	// OK, all digits
	return  intval( $_POST[$varName] );
	} else {
		trigger_error( "\nERROR: Le numéro $varName n'est pas passé par un POST ou est au mauvais format.\n", E_USER_WARNING );
		return NULL;
	}
}

/////////////////////////////////////////////////////////////////////////////////////
// TRAITEMENT DES FORMULAIRES
/////////////////////////////////////////////////////////////////////////////////////
//----------------------------------------------------------------------------------
//Traiter le formulaire d'édition d'un membre de laboratoire
/// Valeurs de retour:
//	  Array( $text_to_display, $membre_id_to_redirect, $page_id_if_created )
//		  $text_to_display = Variable dans laquelle stocker le texte à afficher
//		  $membre_id_to_redirect = ID du membre à afficher une fois le formulaire validé
//		  $page_id_if_created = ID de la page crée en cas de création de membre
//----------------------------------------------------------------------------------
function form_edit_member_processing() {
	$MonLabo_access_data = New MonLabo_access_data();
	$membre_id = 0;
	//Vérification que le formulaire a bien été soumis
	if ( isset( $_POST['submit_first_name'] ) ) {
		$membre_id = intval( $_POST['submit_id'] );
		unset( $_POST['submit_id'] );
		$action = sanitize_key( $_POST['action'] );
		unset( $_POST['action'] );
		if ( $action === 'edit' ) {
			$data = array();
			foreach ( $_POST as $key => $value ) {
				switch ( $key ) {
					case 'submit_teams':
					case 'submit_mentors':
						if ( is_array($_POST[$key]) ) {
							foreach ( $_POST[$key] as $subkey => $subvalue ) {
								$data[str_replace( 'submit_', '', $key )][$subkey] = intval( $_POST[$key][$subkey] );
							}
						} else {
							$data[str_replace( 'submit_', '', $key )] = sanitize_text_field( $_POST[$key] );
						}
						break;
					default:
						//echo $key.'<br />';
						$data[str_replace( 'submit_', '', $key )] = getPOSTstring( $key );
						break;
				}
			}
			if ( !isset( $data['teams'] ) ) {
				//Si aucune équipe n'est renseignée, bien passer un tableau vide.
				$data['teams'] = array();
			}
			if ( !isset( $data['mentors'] ) ) {
				//Si aucun mentor n'est renseigné, bien passer un tableau vide.
				$data['mentors'] = array();
			}
			if ( !isset( $data['students'] ) ) {
				//Si aucun étudiant n'est renseigné, bien passer un tableau vide.
				$data['students'] = array();
			}
			if ( ( !empty( $data['edition_wp_post_id'] ) ) and ( $data['wp_post_id'] ) === '0' ) {
			  //Si wp_post_id est édité, le remplacer par l'url du champs en question
			  $data['wp_post_id'] = $data['edition_wp_post_id'];
			}
			unset( $data['edition_wp_post_id'] );

			if ( empty( $data['fonction'] ) ) {
			  $data['fonction'] = ' |  | ';
			}
			$f = explode( ' | ', $data['fonction'] );
			if ( ( empty( $data['category'] ) ) and ( '' != $f[0] ) ) {
			  $data['category'] = $f[0];
			}
			if ( !isset( $f[1] ) ) { $f[1] = ''; }
			if ( !isset( $f[2] ) ) { $f[2] = ''; }
			if ( $f[1] === '' && $f[2] === '' ) { //Si rien n'est envoyé en argument, ne pas mettre à jour.
			  unset( $data['function_en'] );
			  unset( $data['function_fr'] );
			} elseif ( $data['function_en'] === '' && $data['function_fr'] === '' ) {
				$data['function_en'] = $f[1];
				$data['function_fr'] = $f[2];
			}
			unset( $data['fonction'] );

			//Dans le cas où il n'y a qu'une unité, configurer si la personne en est ou pas le directeur
			$options0 = get_option( 'MonLabo_settings_group0' );
			if ( empty( $options0['MonLabo_uses_unites'] ) ) {
				if ( !empty( $data['is_director'] ) ) {
					//On ajoute la personne comme directeur de la structure principale
					$MonLabo_access_data->add_director_to_an_unit ( $membre_id, MAIN_STRUCT_NO_UNIT );
				} else {
					$MonLabo_access_data->remove_director_from_an_unit( $membre_id, MAIN_STRUCT_NO_UNIT );
				}
			}
			if ( isset( $data['is_director'] ) ) {
				unset( $data['is_director'] );
			}
			if ( 0 === $membre_id ) { // ajout d'un membre
				//Création de la page personnelle
				//-------------------------------
				$options = get_option( 'MonLabo_settings_group2' );
				$wp_title = $data['first_name'].' '.mb_strtoupper( $data['last_name'], 'UTF-8' );
				$wp_post = array( 'post_content'   => '[perso_panel][publications_list]', // The full text of the post.
				'post_title'	 => $wp_title, // The title of your post.
				'post_status'	=> 'publish', // Default 'draft'.
				'post_type'	  => 'page', // Default 'post'.
				'post_parent'	=> $options['MonLabo_perso_page_parent'] // Sets the parent of the new post.
				);
				$wp_post_id = wp_insert_post( $wp_post );

				if ( ( 0 === $wp_post_id ) or ( is_wp_error( $wp_post_id ) ) )  {
					return Array( MonLabo_admin::notice_message( 'error', 'Echec:', 'Impossible de créer la page personnelle.' ), NULL, NULL );
				}
				update_post_meta( $wp_post_id, '_theme_show_page_title', '0' ); //Do not show title

				//Modification de l'image en une de la page WordPress
				//---------------------------------------------------
				if ( $wp_post_id>0 ){ //Si la page existe
				  if ( ( '__no_change__' != $data['image_attachment_id'] ) and ( $data['image_attachment_id']>0 ) ) { //Si une nouvelle image est fournie
					set_post_thumbnail( $wp_post_id, $data['image_attachment_id'] ); //Changer l'image à la une de cette page.
				  }
				}
				unset( $data['image_attachment_id'] );
				unset( $data['image_attachment_url'] );

				// Création de la ligne dans la table MonLabo_members
				//---------------------------------------------------
				$data['wp_post_id'] = $wp_post_id;
				$membre_id = $MonLabo_access_data->insert_person( $data );

				return Array(
							  MonLabo_admin::notice_message( 'info', '', sprintf( __( "Page <a href='%s'>%s</a> crée.", 'MonLabo' ), get_permalink( $wp_post_id ), $wp_title ) ),
							  NULL /*Renvoie sur un nouveau membre*/,
							  $wp_post_id
							);

			} else { // édition d'un membre
				//Modification de l'image en une de la page WordPress
				//---------------------------------------------------
				if ( '0' != $data['wp_post_id'] ){ //Si la page existe
				  if ( ( '__no_change__' != $data['image_attachment_id'] ) and ( $data['image_attachment_id']>0 ) ) { //Si une nouvelle image est fournie
					set_post_thumbnail( $data['wp_post_id'], $data['image_attachment_id'] ); //Changer l'image à la une de cette page.
				  }
				}
				unset( $data['image_attachment_id'] );
				unset( $data['image_attachment_url'] );

				// Modification de la ligne dans la table MonLabo_members
				//-------------------------------------------------------
				$MonLabo_access_data->update_person( $membre_id, $data );
			}
		} elseif ( 'remove' === $action ) {  // suppression d'un membre
			// Passage de la page personnelle en brouillon
			//--------------------------------------------
			$person_information = $MonLabo_access_data->get_person_information( $membre_id );
			if ( property_exists( $person_information, 'wp_post_id' ) ) {
				$my_post = array(
					'ID'		   => $person_information->wp_post_id,
					'post_status'  => 'draft'
				);
				wp_update_post( $my_post );
				// Suppression de la ligne dans la table MonLabo_members
				//------------------------------------------------------
				$MonLabo_access_data->delete_person( $membre_id );
			}
		}
	}
	//En cas de rechargement de la page, récupérer le paramètre dans l'URL
	if ( isset( $_POST['submit_item'] ) ) {
	  $_GET['submit_item'] = intval( $_POST['submit_item'] );
	}
	if ( ( empty( $membre_id ) ) and ( isset( $_GET['submit_item'] ) ) ) {
		$membre_id = intval( $_GET['submit_item'] );
	}
	return Array( '', $membre_id, NULL );
}

//----------------------------------------------------------------------------------
//Traiter le formulaire d'édition d'une équipe
/// Valeurs de retour:
//	  Array( $text_to_display, $team_id_to_redirect, $team_id_if_created )
//		  $text_to_display = Variable dans laquelle stocker le texte à afficher
//		  $team_id_to_redirect = ID de l'équipe à afficher une fois le formulaire validé
//		  $team_id_if_created = ID de l'équipe nouvelle en cas de création
//----------------------------------------------------------------------------------
function form_edit_team_processing() {
	$MonLabo_access_data = New MonLabo_access_data();
	$team_id = 0;
	//Vérification que le formulaire a bien été soumis
	if ( isset( $_POST['submit_name_fr'] ) ) {
		unset( $_POST['not_used'] );
		$team_id = intval( $_POST['submit_id'] );
		unset( $_POST['submit_id'] );
		$action = sanitize_key( $_POST['action'] );
		unset( $_POST['action'] );

		if ( 'edit' === $action ) {
			$data = array();
			foreach ( $_POST as $key => $value ) {
				switch ( $key ) {
					case 'submit_leaders':
					case 'submit_thematics':
						if ( is_array($_POST[$key]) ) {
							foreach ( $_POST[$key] as $subkey => $subvalue ) {
								$data[str_replace( 'submit_', '', $key )][$subkey] = intval( $_POST[$key][$subkey] );
							}
						} else {
							$data[str_replace( 'submit_', '', $key )] = sanitize_text_field( $_POST[$key] );
						}
						break;
					default:
						$data[str_replace( 'submit_', '', $key )] = getPOSTstring( $key );
						break;
				}
			}
			if ( !isset( $data['leaders'] ) ) {
				//Si aucun leader n'est renseigné, bien passer un tableau vide.
				$data['leaders'] = array();
			}
			if ( !isset( $data['thematics'] ) ) {
				//Si aucune thematique n'est renseignée, bien passer un tableau vide.
				$data['thematics'] = array();
			}

			if ( 0 === $team_id ) { // ajout d'une équipe
				// Création de la ligne dans la table MonLabo_teams
				$team_id_if_created = $MonLabo_access_data->insert_team( $data );
				return Array(
							  MonLabo_admin::notice_message( 'info', '', sprintf( __( 'Nouvelle équipe crée (ID=%u).', 'MonLabo' ), $team_id_if_created ) ),
							  NULL /*Renvoie sur une nouvelle équipe */,
							  $team_id_if_created
							);
			} else { // éditon d'une équipe
				// Modification de la ligne dans la table MonLabo_teams
				//-----------------------------------------------------
				$MonLabo_access_data->update_team( $team_id, $data );
			}
		} else {
			if ( 'remove' === $action ) {  // suppression d'un membre
				// Suppression de la ligne dans la table MonLabo_teams
				//----------------------------------------------------
				$MonLabo_access_data->delete_team( $team_id );
			}
		}
	}
	//En cas de rechargement de la page, récupérer le paramètre dans l'URL
	if ( isset( $_POST['submit_item'] ) ) {
	  $_GET['submit_item'] = intval( $_POST['submit_item'] );
	}
	if ( ( empty( $team_id ) ) and ( isset( $_GET['submit_item'] ) ) ) {
		$team_id = intval( $_GET['submit_item'] );
	}
	return Array( '', $team_id, NULL );
}

//----------------------------------------------------------------------------------
//Traiter le formulaire d'édition d'une thématique
/// Valeurs de retour:
//	  Array( $text_to_display, $thematic_id_to_redirect, $thematic_id_if_created )
//		  $text_to_display = Variable dans laquelle stocker le texte à afficher
//		  $thematic_id_to_redirect = ID de la thématique à afficher une fois le formulaire validé
//		  $thematic_id_if_created = ID de la thématique nouvelle en cas de création
//----------------------------------------------------------------------------------
function form_edit_thematic_processing() {
	$MonLabo_access_data = New MonLabo_access_data();
	$thematic_id = 0;
	//Vérification que le formulaire a bien été soumis
	if ( isset( $_POST['submit_name_fr'] ) ) {
		unset( $_POST['not_used'] );
		$thematic_id = intval( $_POST['submit_id'] );
		unset( $_POST['submit_id'] );
		$action = sanitize_key( $_POST['action'] );
		unset( $_POST['action'] );
		if ( 'edit' === $action ) {
			$data = array();
			foreach ( $_POST as $key => $value ) {
				$data[str_replace( 'submit_', '', $key )] = getPOSTstring( $key );
			}
			if ( 0 === $thematic_id ) { // ajout d'une thématique
				// Création de la ligne dans la table MonLabo_thematics
				//-------------------------------------------------------
				$thematic_id_if_created = $MonLabo_access_data->insert_thematic( $data );
				return Array(
							  MonLabo_admin::notice_message( 'info', '', sprintf( __( 'Nouvelle thématique crée (ID=%u).', 'MonLabo' ), $thematic_id_if_created ) ),
							  NULL /*Renvoie sur une nouvelle thématique*/,
							  $thematic_id_if_created
							);
			} else {
				// Modification de la ligne dans la table MonLabo_thematics
				//-----------------------------------------------------------
				$MonLabo_access_data->update_thematic( $thematic_id, $data );
			}
		} elseif ( 'remove' === $action ) {  // suppression d'un membre
				// Suppression de la ligne dans la table MonLabo_thematics
				//----------------------------------------------------------
				$MonLabo_access_data->delete_thematic( $thematic_id );
		}
	}
	//En cas de rechargement de la page, récupérer le paramètre dans l'URL
	if ( isset( $_POST['submit_item'] ) ) {
	  $_GET['submit_item'] = intval( $_POST['submit_item'] );
	}
	if ( ( empty( $thematic_id ) ) and ( isset( $_GET['submit_item'] ) ) ) {
		$thematic_id = intval( $_GET['submit_item'] );
	}
	return Array( '', $thematic_id, NULL );
}

//----------------------------------------------------------------------------------
//Traiter le formulaire d'édition d'une unité
// Valeurs de retour:
//	  Array( $text_to_display, $unit_id_to_redirect, $unit_id_if_created )
//		  $text_to_display = Variable dans laquelle stocker le texte à afficher
//		  $unit_id_to_redirect = ID de l'unité à afficher une fois le formulaire validé
//		  $unit_id_if_created = ID de l'unité nouvelle en cas de création
//----------------------------------------------------------------------------------
function form_edit_unite_processing() {
	$MonLabo_access_data = New MonLabo_access_data();
	$unite_id = 0;
	//Vérification que le formulaire a bien été soumis
	if ( isset( $_POST['submit_name_fr'] ) ) {
		unset( $_POST['not_used'] );
		$unite_id = intval( $_POST['submit_id'] );
		unset( $_POST['submit_id'] );
		$action = sanitize_key( $_POST['action'] );
		unset( $_POST['action'] );

		if ( 'edit' === $action ) {
			$data = array();
			foreach ( $_POST as $key => $value ) {
				switch ( $key ) {
					case 'submit_directors':
						if ( is_array($_POST[$key]) ) {
							foreach ( $_POST[$key] as $subkey => $subvalue ) {
								$data[str_replace( 'submit_', '', $key )][$subkey] = intval( $_POST[$key][$subkey] );
							}
						} else {
							$data[str_replace( 'submit_', '', $key )] = sanitize_text_field( $_POST[$key] );
						}
						break;
					default:
						$data[str_replace( 'submit_', '', $key )] = getPOSTstring( $key );
						break;
				}
			}
			if ( !isset( $data['directors'] ) ) {
				//Si aucun directeur n'est renseigné, bien passer un tableau vide.
				$data['directors'] = array();
			}

			if ( 0 === $unite_id ) { // ajout d'une unité
				// Création de la ligne dans la table MonLabo_units
				//-------------------------------------------------------
				$unit_id_if_created = $MonLabo_access_data->insert_unit( $data );
				return Array(
							  MonLabo_admin::notice_message( 'info', '', sprintf( __( 'Nouvelle unité crée (ID=%u).', 'MonLabo' ), $unit_id_if_created ) ),
							  NULL /*Renvoie sur une nouvelle unité */,
							  $unit_id_if_created
							);
			} else {
				// Modification de la ligne dans la table MonLabo_units
				//-----------------------------------------------------------
				$MonLabo_access_data->update_unit( $unite_id, $data );
			}
		} elseif ( 'remove' === $action ) {  // suppression d'un membre
				// Suppression de la ligne dans la table MonLabo_units
				//----------------------------------------------------------
				$MonLabo_access_data->delete_unit( $unite_id );
		}
	}
	//En cas de rechargement de la page, récupérer le paramètre dans l'URL
	if ( isset( $_POST['submit_item'] ) ) {
	  $_GET['submit_item'] = intval( $_POST['submit_item'] );
	}
	if ( ( empty( $unite_id ) ) and ( isset( $_GET['submit_item'] ) ) ) {
		$unite_id = intval( $_GET['submit_item'] );
	}
	return Array( '', $unite_id, NULL );
}

//----------------------------------------------------------------------------------
//Traiter le formulaire d'édition de la structure principale
//----------------------------------------------------------------------------------
function form_edit_structure_principale_processing() {
	//Vérification que le formulaire a bien été soumis
	if ( isset( $_POST['submit_nom'] ) ) {
		unset( $_POST['not_used'] );
		$options1 = get_option( 'MonLabo_settings_group1' );
		$data = array();
		foreach ( $_POST as $key => $value ) {
			switch ( $key ) {
				case 'submit_nom':
				case 'submit_code':
				case 'submit_prefixe_tel':
				case 'submit_hal_publi_struct_id':
					$options1[str_replace( 'submit_', 'MonLabo_', $key )] = sanitize_text_field( $value );
					break;
				case 'submit_contact':
				case 'submit_adresse':
					$options1[str_replace( 'submit_', 'MonLabo_', $key )] = sanitize_textarea_field( $value );
					break;
			}
		}

		update_option( 'MonLabo_settings_group1', $options1 );
		$options1 = get_option( 'MonLabo_settings_group1' );

		//Gestion des directeurs
		$MonLabo_access_data = New MonLabo_access_data();
		$data = array();
		if ( !isset( $_POST['submit_directors'] ) ) {
			//Si aucun directeur n'est renseigné, bien passer un tableau vide.
			$data['directors'] = array();
		} else {
			if (is_array( $_POST['submit_directors'] ) ) {
				foreach ( $_POST['submit_directors'] as $key => $value) {
					$data['directors'][$key]= intval( $value );
				}
			} else {
				$data['directors']= sanitize_text_field( $_POST['submit_directors'] );
			}
		}

		// Modification de la ligne dans la table MonLabo_units
		//-----------------------------------------------------------
		$MonLabo_access_data->update_unit( MAIN_STRUCT_NO_UNIT, $data );
	}
}

//----------------------------------------------------------------------------------
//Traiter les formulaires d'outils avancés
//----------------------------------------------------------------------------------
function form_advanced_features_for_members_processing() {
  $retval = '';
  if ( isset( $_POST['create_missing_pages_submit_ids'] ) ) {
	$ids_to_create_page = ( unserialize( sanitize_text_field( $_POST['create_missing_pages_submit_ids'] ) ) );
	if ( !empty( $ids_to_create_page ) ) {
	  foreach ( $ids_to_create_page as $id ) {
		$id = intval( $id );
		if ( !empty( $id ) ) {
		  $MonLabo_access_data = New MonLabo_access_data();
		  $member = $MonLabo_access_data->get_person_information( $id );
		  if ( !empty( $member ) ) {


			//Création de la page personnelle
			//-------------------------------
			$options2 = get_option( 'MonLabo_settings_group2' );
			$wp_title = $member->first_name.' '.mb_strtoupper( $member->last_name, 'UTF-8' );
			$wp_post = array( 'post_content'   => '[perso_panel][publications_list]', // The full text of the post.
			'post_title'	 => $wp_title, // The title of your post.
			'post_status'	=> 'publish', // Default 'draft'.
			'post_type'	  => 'page', // Default 'post'.
			'post_parent'	=> $options2['MonLabo_perso_page_parent'] // Sets the parent of the new post.
			);

			$wp_post_id = wp_insert_post( $wp_post );
			$retval .=   MonLabo_admin::notice_message(
				'info',
				'',
				sprintf( __( 'Page de personnel crée (%s - %s)', 'MonLabo' ),
				$wp_title,
				"<a href='".get_edit_post_link( $wp_post_id )."'>".__( 'éditer la page', 'MonLabo'
			).'</a>' ) );
			if ( ( 0 === $wp_post_id ) or ( is_wp_error( $wp_post_id ) ) )  {
				return MonLabo_admin::notice_message( 'error', 'Echec:', 'Impossible de créer la page personnelle.' );
			}
			update_post_meta( $wp_post_id, '_theme_show_page_title', '0' ); //Do not show title

			// Modification de la ligne dans la table MonLabo_members
			//-------------------------------------------------------
			$data = array();
			$data['id'] = $id;
			$data['wp_post_id'] = $wp_post_id;
			$MonLabo_access_data->update_person( $id, $data );

		  }
		}
	  }
	}
  }
  return $retval;
}

/////////////////////////////////////////////////////////////////////////////////////
// GENERATION D'ELEMENTS
/////////////////////////////////////////////////////////////////////////////////////
function generate_champ_formulaire_pub( $typeOfField, $isMandatory, $legend, $description, $valeur_initiale = '', $id = '' ) {
	switch ( $typeOfField ) {
		case 'descartes_publi_author_id':
			return generate_number_form( $isMandatory, $legend, 'submit_'.$typeOfField, $description, $valeur_initiale, $id );
		case 'external_url':
		case 'edition_wp_post_id':
			return generate_url_form( $isMandatory, $legend, 'submit_'.$typeOfField, $description, $valeur_initiale, $id );
		/*
		//Non utilisé
		case 'title':
			return generate_text_form_small( $isMandatory, $legend, 'submit_'.$typeOfField, $description, $valeur_initiale, $id );*/

		case 'color':
			return generate_color_form( $isMandatory, $legend, 'submit_'.$typeOfField, $description, $valeur_initiale, $id );

		case 'logo':
			return generate_square_image_form( $isMandatory, $legend, 'submit_'.$typeOfField, $description, $valeur_initiale, $id );

		case 'adresse':
		case 'address_alt':
		case 'contact':
		case 'contact_alt':
			return generate_textarea_form( $isMandatory, $legend, 'submit_'.$typeOfField, $description, $valeur_initiale, $id );
		default:
			return generate_text_form_large( $isMandatory, $legend, 'submit_'.$typeOfField, $description, $valeur_initiale, $id );
	}
}

/*----------------------------------------------------------------------------
generate_champ_formulaire_select_page : Génère une liste déroulante de pages WordPress
Paramètres:
	$name : Nom de la liste déroulante
	$isMandatory : [true/false] le choix est-il obligatoire?
	$legend : Texte du nom de la liste déroulante qui sera affiché avant
	$description: Commentaire affiché à coté de la liste déroulante
	$valeur_initiale : Pré-sélection éventuelle d'un item de la liste
	$child_of :( integer ) Displays the sub-pages of a single Page only; uses the ID for a Page as the value. Defaults to 0 (displays all Pages ).
	$depth : ( integer )This parameter controls how many levels in the hierarchy of pages are to be included in the list generated by wp_list_pages. The default value is 0 (display all pages, including all sub-pages ).
	  0 - Pages and sub-pages displayed in hierarchical ( indented ) form ( Default ).
	  -1 - Pages in sub-pages displayed in flat (no indent ) form.
	  1 - Show only top level Pages
	  2 - Value of 2 (or greater) specifies the depth (or level) to descend in displaying Pages.
Valeur de retour:
	Code HTML de la liste déroulante
------------------------------------------------------------------------------*/
function generate_champ_formulaire_select_page( $name, $isMandatory, $legend, $description, $valeur_initiale, $child_of, $depth = 1 ) {
	$retval = '<div class="input-group">';
	$retval .='<label for="submit_'.$name.'">'.$legend;
	if ( !$isMandatory ) { $retval .= ' <small>'.__( '(facultatif)', 'MonLabo' ).'</small>'; }
	$retval .='</label>';
	$retval .='<div class="input-group-addon"></div>';
	$retval .= wp_dropdown_pages(
				   array(
					 'child_of' => $child_of,
					 'depth' => $depth,
					 'name'			  => 'submit_'.$name,
					 'echo'			  => 0,
					 'show_option_none'  => '&mdash; '.__( 'Pas de page ou adresse spéciale', 'MonLabo' ).' &mdash; ',
					 'option_none_value' => '0',
					 'selected'		  => $valeur_initiale,
				   ) );
	$retval .= '<div class="description">'.$description.' </div></div>';
	return $retval;
}


/*----------------------------------------------------------------------------
generate_champ_formulaire_select : Génère une liste déroulante HTML <Select>
Paramètres:
	voir generate_champ_formulaire_select_generic
Valeur de retour:
	Code HTML de la liste déroulante
------------------------------------------------------------------------------*/
function generate_champ_formulaire_select( $name, $values, $isMandatory, $legend, $description, $valeur_initiale = '', $onchange = '' ) {
	return generate_champ_formulaire_select_generic( $name, $values, $isMandatory, $legend, $description, false, $valeur_initiale, $onchange );
}

/*----------------------------------------------------------------------------
generate_champ_formulaire_select_multiple :
	Génère une liste déroulante HTML à choix multiple
Paramètres:
	voir generate_champ_formulaire_select_generic
Valeur de retour:
		Code HTML de la liste déroulante
------------------------------------------------------------------------------*/
function generate_champ_formulaire_select_multiple( $name, $values, $isMandatory, $legend, $description, $valeur_initiale = array(), $onchange = '' ) {
	return generate_champ_formulaire_select_generic( $name, $values, $isMandatory, $legend, $description, true, $valeur_initiale, $onchange );
}

/*----------------------------------------------------------------------------
generate_champ_formulaire_select_generic :
	Génère une liste déroulante HTML simple ou à choix multiple
Paramètres:
	$name : Nom de la liste déroulante
	$values : Tableau contenant les items de la liste déroulante.
				Les items peuvent être une simple liste ou des tableau de
				regroupement de liste.
				Chaque item peut être donc de deux formes diférentes. Soit :
					'Valeur' => 'Légende'
				ou bien :
					'Nom du regroupement' => [  'Valeur1' => 'Légende 1',
												'Valeur2' => 'Légende 2',
												...
											]
	$isMandatory : [true/false] le choix est-il obligatoire?
	$legend : Texte du nom de la liste déroulante qui sera affiché avant
	$description: Commentaire affiché à coté de la liste déroulante
	$selectmultiple : [true/false] si true, génère liste à choix multiple
	$valeur_initiale : Deux possibilités:
		- Liste à choix simple: Pré-sélection éventuelle d'un item de la liste
		- Liste à choix multiple : Tableau listant les pré-sélection éventuelle d'items de la liste
	$onchange : Code javascript éventuel qui sera exécuté en cas de changement
				de sélection dans la liste déroulante.

Valeur de retour:
	Code HTML de la liste déroulante
------------------------------------------------------------------------------*/
function generate_champ_formulaire_select_generic( $name, $values, $isMandatory, $legend, $description, $selectmultiple = false, $valeur_initiale = array(), $onchange = '' ) {
	$retval = '<div class="input-group">';
	$retval .= '<label for="submit_'.$name.'">'.$legend;
	if ( !$isMandatory ) { $retval .= ' <small>'.__( '(facultatif)', 'MonLabo' ).'</small>'; }
	$retval .= '</label>';
	$retval .= '<div class="input-group-addon"></div>';
	$retval .= '<select '.($selectmultiple ? "multiple " : "" ).'class="form-control" name="submit_'.$name.($selectmultiple ? "[]" : "" ).'"';
	$retval .= ' id="submit_'.$name.'"';
	if ( $isMandatory ) { $retval .= ' required'; }
	if ( '' != $onchange ) {
		$retval .= ' onchange="'.$onchange.'"';
	}
	$retval .= '>';
	foreach ( $values as $key => $value ) {
		if ( !is_array( $value ) ) {
			$retval .= '<option value="'.$key.'"';
			if ( true === $selectmultiple ) {
				if ( ( null != $valeur_initiale ) and ( in_array( $value, $valeur_initiale ) ) ) {
					$retval .= ' selected';
				}
			} else {
				if ( ( strlen( $valeur_initiale ) > 0 ) && ( $valeur_initiale === $value ) ) {
					$retval .= ' selected';
				}
			}
			$retval .= '>'.$value.'</option>';
		} else {
			//Avec des optgroup si tableau de tableau
			$retval .= '<optgroup label="'.$key.'">';
				foreach ( $value as $sub_key=>$sub_value ) {
					$retval .= '<option value="'.$sub_key.'"';
					if ( true === $selectmultiple ) {
						if ( ( null != $valeur_initiale ) and ( in_array( $sub_value, $valeur_initiale ) ) ) {
							$retval .= ' selected';
						}
					} else {
						if ( ( strlen( $valeur_initiale ) > 0 ) && ( $valeur_initiale === $sub_value ) ) {
							$retval .= ' selected';
						}
					}
					$retval .= '>'.$sub_value.'</option>';
				}
			$retval .= '</optgroup>';
		}
	}
	$retval .= '</select><div class="description">'.$description.' </div></div>';
	return $retval;
}

function generate_champ_formulaire_radio( $name, $values, $isMandatory, $legend, $description, $valeur_initiale = '', $onchange = '' ) {
	$retval = '<div class="input-group">';
	$retval .= '<label for="submit_'.$name.'">'.$legend;
	if ( !$isMandatory ) { $retval .= ' <small>'.__( '(facultatif)', 'MonLabo' ).'</small>'; }
	$retval .= '</label>';
	$retval .= '<div class="input-group-addon"></div>';
	foreach ( $values as $key => $value ) {
		$retval .= '<input type="radio" class="form-control" id="submit_'.$name.'_'.$key.'" name="submit_'.$name.'"';
		if ( $isMandatory ) { $retval .= ' required '; }
		if ( '' != $onchange ) {
			$retval .= ' onchange="'.$onchange.'"';
		}
		$retval .= 'value="'.$key.'"';
		if ( ( strlen( $valeur_initiale ) > 0 ) && ( $valeur_initiale === $value ) ) {
			$retval .= ' checked';
		}
		$retval .= ' />'.$value.'<br />';
	}
	$retval .= '<div class="description">'.$description.' </div></div>';
	return $retval;
}

function generate_champ_formulaire_checkboxes( $name, $values, $isMandatory, $legend, $description, $valeur_initiale = array() ) {
	$retval = '<div class="input-group">';
	reset( $values );
	$first_key_of_values = key( $values );
	$retval .= '<label for="sumbit_'.$name.'_'.$first_key_of_values.'">'.$legend;
	if ( !$isMandatory ) { $retval .= ' <small>'.__( '(facultatif)', 'MonLabo' ).'</small>'; }
	$retval .= '</label>';
	$retval .= '<div class="input-group-addon"></div>';
	$retval .= '<div class="checkboxes-group"';
	$retval .= ' >';
	foreach ( $values as $key => $value ) {
		if ( ( null != $valeur_initiale ) and ( in_array( $value, $valeur_initiale ) ) ) {
			$retval .= '<input type="checkbox" name="submit_'.$name.'['.$key.']" id="submit_'.$name.'_'.$key.'" value="'.$key.'" checked /> '. $value.'<br />';
		} else {
			$retval .= '<input type="checkbox" name="submit_'.$name.'['.$key.']" id="submit_'.$name.'_'.$key.'" value="'.$key.'" /> '. $value.'<br />';
		}
	}
	$retval .= '</div>';
	$retval .= '<div class="description">'.$description.' </div></div>';
	return $retval;
}

function generate_textarea_form( $isMandatory, $legend, $name, $description, $valeur_initiale = '', $id ) {
	$retval = '<div class="input-group">';
	$retval .= '<div class="input-group-addon"></div>';
	$value = $valeur_initiale;
	$retval .= '<textarea rows="3" name="'.$name.'">'.$value.'</textarea>';
	$retval .= '<div class="description">'.$description.' </div></div>';
	return $retval;
}

function generate_text_form_large( $isMandatory, $legend, $name, $description, $valeur_initiale = '', $id ) {
	return generate_form_field( $isMandatory, $legend, 'text', $name, $description, 'input-group-large', $id,
						$valeur_initiale );
}
/*
//Non utilisé
function generate_text_form_normal( $isMandatory, $legend, $name, $description, $valeur_initiale = '', $id ) {
	return generate_form_field( $isMandatory, $legend, 'text', $name, $description, 'input-group', $id,
						$valeur_initiale );
}*/
/*
//Non utilisé
function generate_text_form_small( $isMandatory, $legend, $name, $description, $valeur_initiale = '', $id ) {
	return generate_form_field( $isMandatory, $legend, 'text', $name, $description, 'input-group-small', $id,
						$valeur_initiale );
}*/

function generate_url_form( $isMandatory, $legend, $name, $description, $valeur_initiale = '', $id ) {
	return generate_form_field( $isMandatory, $legend, 'url', $name, $description, 'input-group-large', $id,
						$valeur_initiale );
}

function generate_number_form( $isMandatory, $legend, $name, $description, $valeur_initiale = '', $id ) {
	return generate_form_field( $isMandatory, $legend, 'number', $name, $description, 'input-group-normal nopadding-input', $id,
					$valeur_initiale );
}

function generate_form_field( $isMandatory, $legend, $input_type, $name, $description, $imput_group_class = '',
		$imput_id = '', $valeur_initiale = '', $input_class = '', $input_custom = '' ) {
	$to_display = '<div class="input-group '.$imput_group_class.'">';
	$to_display .= '<div class="input-group-addon"></div>';
	if ( !empty( $input_class ) ) { $input_class = ' '.$input_class; }
	$to_display .= '<input type="'.$input_type.'" class="form-control'.$input_class.'" name="'.$name.'" placeholder="'.$legend;
	if ( !$isMandatory ) { $to_display .= ' ('.__( 'facultatif', 'MonLabo' ).')'; }
	$to_display .= '"';
	if ( !empty( $imput_id ) ) { $to_display .= ' id="'.$imput_id.'"'; }
	if ( strlen( $valeur_initiale ) > 0 ) { $to_display .= " value=\"$valeur_initiale\""; }
	if ( $isMandatory ) { $to_display .= ' required'; }
	if ( !empty( $input_custom ) ) { $to_display .= ' '.$input_custom; }
	$to_display .= ' /><div class="description"> '.$description.' </div></div>';
	return $to_display;
}

function generate_color_form( $isMandatory, $legend, $name, $description, $valeur_initiale = '', $id ) {
	return generate_form_field( $isMandatory, $legend, 'text', $name, $description, "input-group-normal nopadding-input", $id,
					$valeur_initiale, 'my-color-field', "data-default-color='#effeff'" );
}

function generate_square_image_form( $isMandatory, $legend, $name, $description, $valeur_initiale, $id ) {
	$retval = '<div class="input-group"><label for="'.$name.'">'.$description.' : </label>';
	$retval .= '<input id="'.$name.'_no_logo_button" class="button" value="'.__( "Aucun", "MonLabo" ).'"';
	$retval .= ' onclick="selectNoPicture(\''.$name.'-image-preview\', \''.$name.'\', \''.$name.'-image_attachment_id\');" type="button" />';
	$retval .= '&nbsp;<input id="'.$name.'_upload_image_button" type="button" class="button" value="'. __( 'Choisir média', 'MonLabo' ).'"';
	$retval .= ' onclick="imageMediaMenu(\''. __( 'Choisir une image', 'MonLabo' ).'\',\''. __( 'utiliser cette image', 'MonLabo' ).'\', ';
	$retval .=							 '\''.$name.'-image-preview\', \''.$name.'\', \''.$name.'-image_attachment_id\');" />';
	$retval .= "<input type='hidden' name='not_used' id='".$name."-image_attachment_id' value='0' />";
	if ( !empty( $valeur_initiale ) ) {
		$retval .= "&nbsp;<a href='#' class='hover-zoom-square30'><img width='30' height='30' id='".$name."-image-preview' class='wp-image-8 wp-post-image' src='".$valeur_initiale."' alt='".$valeur_initiale."'></a>";
	}
		$retval .= '</div><div class="hidden">'.generate_champ_formulaire_pub( $name, $isMandatory, '', get_MonLabo_Team_fields_comments( $name ), $valeur_initiale, $name ).'</div>';
	return $retval;
}


function generate_submit_button( $text, $id = '', $on_click = '' ) {
	if ( '' != $id ) { $id_text = ' id="'.$id.'"'; }
	else { $id_text = ''; }
	$retval = '<button ';
	if ( '' != $on_click ) { $retval .= 'onclick="'.$on_click.'" '; }
	$retval .= 'type="submit" class="btn btn-primary"'.$id_text.'>';
	$retval .= $text.'</button>';
	return $retval;
}

?>
