/**
 * Scripts for the admin interface.
 *
 * Theses functions are used in the administration pages of the plugin.
 *
 * @link   https://monlabo.org/
 * @author Hervé Suaudeau.
 * @since  1.4.0 at least
 */

/**
 * Person edition page : Started when the category is changed.
 *
 * Function started when touching a selector to chose the category of a
 * person. It changes the selection of person's functions.
 *
 * @fires select[name='submit_category']:change in page "Edit persons"
 *
 * @since 2.2.0 with name touchCategoryNouvelAuteur
 * @since 2.8.0 renamed touchPersonCategory
 */
function touchPersonCategory() {

	// Gets the category chosen by the selector
	var categoryChosen = jQuery( "select[name='submit_category']" ).val();

	// Shows optgroup of the chosen category
    jQuery( "select[name='submit_fonction'] optgroup" ).hide();
	jQuery( "select[name='submit_fonction'] optgroup[label='" + categoryChosen + "']" ).show();
}


/**
 * Person edition page : Started when the status is changed.
 *
 * Function started when touching a selector to change the status of a
 * person. It displays the form of departures date if the status is chosen
 * to alumni.
 *
 * @fires select[name='submit_status']:change in page "Edit persons"
 *
 * @since 2.5.1 with name touchStatusNouvelAuteur
 * @since 2.8.0 renamed touchPersonStatus
 */
function touchPersonStatus() {

	// Gets the item chosen by the selector
	var itemChosen = jQuery( "select[name='submit_status']" ).val();

	// Hides of shows departures date form
	if ( itemChosen === 'actif' ) {
		jQuery( '#MonLabo-date-departure-form' ).hide();
	} else {
		jQuery( '#MonLabo-date-departure-form' ).show();
	}
}


/**
 * Person edition page : Started when the function is changed.
 *
 * Function started when touching a selector to change the function of a
 * person. It updates the editing fields of the function.
 *
 * @fires select[name='submit_fonction']:change in page "Edit persons"
 *
 * @since 1.4.0 with name touchFonctionNouvelAuteur
 * @since 2.8.0 renamed touchPersonFunction
 */
function touchPersonFunction() {

	// Gets the item chosen by the selector
	// item chosen is of the form 'category | function_en | function_fr'
	var fonctions = jQuery( "select[name='submit_fonction']" ).val().split( ' | ' );

	// Updates the editing fields of the function.
	jQuery( "input[name='submit_function_en']" ).val( fonctions[ 1 ] );
	jQuery( "input[name='submit_function_fr']" ).val( fonctions[ 2 ] );
}


/**
 * Person edition page : loads thumbnail picture of a person.
 *
 * Asynchronus loads thumbnail.
 *
 * @since 2.1.0 with name ajax_load_post_thumbnail_now
 * @since 2.8.0 renamed ajaxLoadPostThumbnailNow
 */
function ajaxLoadPostThumbnailNow() {
	if ( jQuery( '#delayedLoadDivThumbnail' ).length ) {
		var data = {
			'action': 'update_member_thumbnail',
			'wp_post_id': jQuery( "select[name='submit_wp_post_id']" ).val()
		};

		// We can also pass the url value separately from ajaxurl for front end AJAX implementations
		jQuery.post( ajax_object_update_member_thumbnail.ajax_url, data, function( response ) {
			jQuery( '#delayedLoadDivThumbnail' ).hide();
			jQuery( '#delayedLoadDivThumbnail' ).html( response );
			jQuery( '#delayedLoadDivThumbnail' ).fadeIn( 500 );
		});
	}
}


/**
 * Displays media menu in order to chose a picture.
 *
 * Uses media menu from WordPress.
 *
 * @since 2.1.0 with name image_media_menu
 * @since 2.8.0 renamed imageMediaMenu
 */
function imageMediaMenu( titleText = 'Images',
	buttonText = 'OK',
	imagePreviewFieldId = 'image-preview',
	imageAttachementUrlFieldId = 'image_attachment_url',
	imageAttachementIdFieldId = 'image_attachment_id' ) {

	// Creates the media frame.
	var file_frame = wp.media.frames.file_frame = wp.media( {
		title: titleText,
		button: {
			text: buttonText
		},
		multiple: false // Set to true to allow multiple files to be selected
	} );
	var url;

	// When an image is selected, runs a callback.
	file_frame.on( 'select', function() {

		// Set multiple to false so only gets one image from the uploader
		var attachment = file_frame.state().get( 'selection' ).first().toJSON();
		var urlThubmnail;
		if ( ( attachment.sizes ) && ( attachment.sizes.thumbnail ) && ( attachment.sizes.thumbnail.url ) ) {
			urlThubmnail = attachment.sizes.thumbnail.url;
		} else {
			urlThubmnail = attachment.url;
		}

		// Does something with attachment.id and/or attachment.url here
		jQuery( '#' + imagePreviewFieldId ).attr( 'src', urlThubmnail ).css( 'width', 'auto' );
		jQuery( '#' + imagePreviewFieldId ).removeAttr( 'srcset' );
		jQuery( '#' + imageAttachementUrlFieldId ).val( urlThubmnail );
		jQuery( '#' + imageAttachementIdFieldId ).val( attachment.id );
	});

	// Finally, opens the modal
	file_frame.open();
}

/**
 * Displays the edit fields of the persons functions.
 *
 * @since 2.1.0 with name affiche_edition_fonctions_fields
 * @since 2.8.0 renamed displaysEditFunctionsFields
 */
function displaysEditFunctionsFields() {
	jQuery( '#edit-functions-fields' ).show();
}

/**
 * Displays the edit page address.
 *
 * Lauched when edit button of wp_post_id field is pushed.
 *
 * @since 2.1.0 with name affiche_edition_wp_post_id
 * @since 2.8.0 renamed displaysEditPageAddress
 */
function displaysEditPageAddress() {

	// Displays editing field of URL
	jQuery( '#edit-wp-post-id-field' ).show();

	// Fills with the permalink of the WordPress page
	jQuery( "input[name='submit_edition_wp_post_id']" ).val( jQuery( '#wp_post_id_post_link' ).val());

	// Updates selection
	jQuery( '#submit_wp_post_id' ).val( '0' );

	// Updates thumbnail
	ajaxLoadPostThumbnailNow();
}

/**
 * Select no picture
 *
 * Lauched when "none" button is pushed when chosing a picture.
 *
 * @since 2.1.0 with name effacer_choix_media
 * @since 2.8.0 renamed selectNoPicture
 */
function selectNoPicture( imagePreviewFieldId = 'image-preview',
	imageAttachementUrlFieldId = 'image_attachment_url',
	imageAttachementIdFieldId = 'image_attachment_id' ) {
	jQuery( '#' + imageAttachementUrlFieldId ).val( '' );
	jQuery( '#' + imageAttachementIdFieldId ).val( '' );
	jQuery( '#' + imagePreviewFieldId ).attr( 'src', '' ).css( 'width', 'auto' );
	jQuery( '#' + imagePreviewFieldId ).removeAttr( 'srcset' );
}

/**
 * Changes a selection value of an idem in the edit page.
 *
 * @since 2.4.0 with name change_item
 * @since 2.8.0 renamed changeItem
 *
 * @param {String} formId ID of the form
 * @param {String} itemId ID of the item (person, team, group or unit) to treat
 */
function changeItem( formId, itemId ) {

	// Adds in _GET the member's number to get it back in case of reloading the page
	jQuery( '#' + formId ).attr( 'action', jQuery( location ).attr( 'href' ) + '&submit_item=' + itemId );

	// Validates the form and reloads the page
	document.forms[ formId ].submit();
}

function changeMember( val ) {
	changeItem( 'choix_membre', val );
}

function changeTeam( val ) {
	changeItem( 'choix_equipe', val);
}

function changeThematic( val ) {
	changeItem( 'choix_thematique', val);
}

function changeUnite( val ) {
	changeItem( 'choix_unite', val);
}


/**
 * Edit of suppress a person or structure
 *
 * @since 2.4.0 with name submit_form
 * @since 2.8.0 renamed submitForm
 *
 * @param {String} formId ID of the form
 * @param {String} action action to do if form is submited
 */
function submitForm( formId, action ) {

	// Schedules the action when the page reloads
	document.getElementById( 'action' ).value = action;
	if (jQuery( '#form_edit_member' ).length ) {

		// Displays the hidden fields to understand why the submit is refused if they are empty
		displaysEditFunctionsFields();
	}

	// Validates the form and reloads the page
	document.forms[ formId ].submit();
}

function edit_member() {
	submitForm( 'form_edit_member', 'edit' );
}

function removeMember() {
	submitForm( 'form_edit_member', 'remove' );
}

function edit_team() {
	submitForm( 'form_edit_team', 'edit' );
}

function removeTeam() {
	submitForm( 'form_edit_team', 'remove' );
}

function edit_thematic() {
	submitForm( 'form_edit_thematic', 'edit' );
}

function removeThematic() {
	submitForm( 'form_edit_thematic', 'remove' );
}

function edit_unite() {
	submitForm( 'form_edit_unite', 'edit' );
}

function removeUnite() {
	submitForm( 'form_edit_unite', 'remove' );
}

/**
 * On loads function
 */
jQuery( document ).ready( function($) {
	jQuery( '.my-color-field' ).wpColorPicker();

	ajaxLoadPostThumbnailNow();

	// Displays the wp_post_id editing form if it has already been edited
	if ( document.getElementById( 'wp_post_id_edited' ) ) {
		if ( jQuery( '#wp_post_id_edited' ).val().length != 0 ) {
			 jQuery( '#edit-wp-post-id-field' ).show();
		}
	}

	// Configurations for the members edit page
	if ( jQuery( '#form_edit_member' ).length) {

		// Activates touch scripts on load
		touchPersonCategory();
		touchPersonFunction();
		touchPersonStatus();

		// Enables update touch scripts if the category of function selectors are affected
		jQuery( "select[name='submit_category']" ).on( 'change', touchPersonCategory );
		jQuery( "select[name='submit_status']"   ).on( 'change', touchPersonStatus   );
	}


});
