<?php
defined( 'ABSPATH' ) or die( 'No direct script access allowed' );

/**
 * Class MonLabo_persons
 *
 * @package
 */

class MonLaboLib {

	//--------------------------------------------------------------------------------
	// Fonction  qui prend une valeur sous forme 'a,b,c,d' et retourne un array
	// ['a', 'b', 'c', 'd']
	// On peut aussi fournir une valeur sour la forme 'a|b|c|d' ou 'a;b;c;d'.
	//--------------------------------------------------------------------------------
	public static function prepare_multiple_values_variable_into_array( $inputs ) {
		if ( !is_array( $inputs ) ) {
			$inputs = str_replace( '|', ',', $inputs ); //Pouvoir utiliser | comme separateur
			$inputs = str_replace( ';', ',', $inputs ); //Pouvoir utiliser ; comme separateur
			if ( !empty( $inputs ) ) {
				$inputs = explode( ',', $inputs ); //Transformation en array
			} else {
				$inputs = array();
			}
		}
		//Suppress empty entries in array
		if ( !empty( $inputs ) ) {
			foreach( $inputs as $key=>$input ) {
				if ( empty( $input ) ) {
					unset( $inputs[$key] );
				}
			}
		}
		return $inputs;
	}



	//--------------------------------------------------------------------------------
	// Simple function to return a prefixed phone from table MonLabo_members
	//--------------------------------------------------------------------------------
	// $phone   => Phone grabbed in table MonLabo_members
	// $html_strong_extension ==> if true return extension number into <strong> tag
	//--------------------------------------------------------------------------------
	public static function get_phone_with_prefix( $phone, $html_strong_extension = 'false' ) {
		if ( $phone<>'' AND $phone[0] === '+' ) {   //The phone is already with a prefix
			return $phone;
		} elseif ( $phone<>'' ) {  //Get the prefix
			$options = get_option( 'MonLabo_settings_group1' );
			if ( is_bool( $html_strong_extension ) ) { $html_strong_extension = ( $html_strong_extension ) ? 'true' : 'false'; }
			if ( 'false' == $html_strong_extension ) {
				return $options['MonLabo_prefixe_tel'].' '. $phone ;
			} else {
				return $options['MonLabo_prefixe_tel'].' <strong>'. $phone .'</strong>';
			}
		}
		return '';
	}

	/**
	 * Return the first key of the array
	 * @param array $myarray array where to extract value
	 * @return mixed|null value extracted
	 * NULL if no result is found
	 * @access public
	 */
	public static function first_key_of_array( $myarray ) {
		$val = NULL;
		if ( !empty( $myarray ) ) {
			$keys = array_keys( $myarray );
			if ( isset( $keys[0] ) ) {
			//if ( array_key_exists( '0', $keys ) ) {
				$val = $keys[0];
			}
		}
		return ( empty( $val ) ? NULL : $val );
	}


	public static function  get_teamGroupName_pl() {
		$options0 = get_option( 'MonLabo_settings_group0' );
		switch ( get_locale() ) {
			case 'en_US':
			case 'en_GB':
				return $options0['MonLabo_teamGroupName_en_pl'];
			default:
				return $options0['MonLabo_teamGroupName_fr_pl'];
		}
	}

	/**
	 * Met en majuscules pour de l'affichage HTML
	 */
	public static function strtoupper_to_html( $string ) {
		return  htmlspecialchars( mb_strtoupper( $string, 'UTF-8' ),
						ENT_HTML5 | ENT_QUOTES, /*Convertit ', ", &, < et > */
						'UTF-8',
						false ); /*Convertit les code HTML déjà présents*/
	}

	/* Convertit l'affichage en code HTML
	*/
	public static function to_html( $string ) {
	   return  htmlspecialchars( $string,
					   ENT_HTML5 | ENT_QUOTES, /*Convertit ', ", &, < et > */
					   'UTF-8',
					   false ); /*Convertit les code HTML déjà présents*/
	}

	/* Renvoie l'URL de la page courante sans éventuelle chaine de requeête supplémentaire ( ?foo = bar&toto )
	*/
	public static function get_current_url_without_queries() {
	$protocol = ( ( !empty( $_SERVER['HTTPS'] ) && $_SERVER['HTTPS'] != 'off' ) || $_SERVER['SERVER_PORT'] == 443 ) ? 'https://' : 'http://';
		return $protocol . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
	}

}


?>
