<?php
defined( 'ABSPATH' ) or die( 'No direct script access allowed' );

///////////////////////////////////////////////////////////////////////////////////////////
// Librairie de fonctions pour manipuler les groupes de personnes.
///////////////////////////////////////////////////////////////////////////////////////////
/**
 * Class MonLabo_persons
 *
 * @package
 */

/*
	suppress_non_visible()
	extract_and_suppress_direction( $suppress_direction )
	extract_and_suppress_team_leaders( $suppress_leader )
	sort_by_name()
	filter_with_categories( $categories )
	filter_with_ids( $persons_ids )
	filter_with_teams( $teams )
	filter_with_units( $units )
*/
class MonLabo_persons {

	private $persons_table;

	public function __construct( $persons_table = array() ) {
		if ( !is_array( $persons_table ) ) { $persons_table = array(); }
		$this->persons_table = $persons_table;
	}

	public function get_persons() {
		return $this->persons_table;
	}

	public function count() {
		return count( $this->persons_table );
	}

	//--------------------------------------------------------------------------------
	// Suppress persons from a list that are not visible
	//--------------------------------------------------------------------------------
	public function suppress_non_visible() {
		if ( !empty( $this->persons_table ) ) {
			// supprime les personnes qui doivent être invisible
			$key_to_suppress = array();
			foreach ( $this->persons_table as $key => $person ) {
				if ( property_exists( $person, 'visible' ) ) {
					if ( strcmp( $person->visible, 'non' ) === 0 ) {
						$key_to_suppress[$key] = $key;
					}
				}
			}
			if ( !empty( $key_to_suppress ) ) {
				foreach ( $key_to_suppress as $key => $dummy ) {
					unset( $this->persons_table[$key] );
				}
			}
		}
		return $this;
	}

	//--------------------------------------------------------------------------------
	// Extrait les ( co)directeurs/directrices d'un tableau de $persons_information
	//--------------------------------------------------------------------------------
	public function extract_and_suppress_direction( $suppress_direction = true ) {
		//TODO: Ajouter une vérification que le directeur est bien celui d'une équipe filtrée
		$MonLabo_access_data = New MonLabo_access_data();
		$table_of_directors = array();
		//Extraire les directeurs du tableau initial
		if ( !empty( $this->persons_table ) ) {
			foreach ( $this->persons_table as $key => $person ) {
				if ( property_exists( $person, 'id' ) ) {
					//if the person is a director
					$units_id_for_a_director = $MonLabo_access_data->get_units_id_for_a_director( $person->id );
					if ( !empty( $units_id_for_a_director ) ) {
						$table_of_directors[$key] = $person;
					}
				}
			}
		}
		//Effacer les directeurs du tableau initial
		if ( $suppress_direction ) {
			if ( !empty( $table_of_directors ) ) {
				foreach ( $table_of_directors as $key => $dummy ) {
					unset( $this->persons_table[$key] );
				}
			}
		}
		return New MonLabo_persons( $table_of_directors );
	}

	//--------------------------------------------------------------------------------
	// Extrait les team leader d'un tableau de $persons_information
	//--------------------------------------------------------------------------------
	public function extract_and_suppress_team_leaders( $suppress_leaders = true ) {
		$MonLabo_access_data = New MonLabo_access_data();
		$table_of_leaders = array();

		//Calcule les leaders autorisés ( restreints aux équipes filtrées )
		if ( !empty( $this->team_filter ) ) {
			$permit_leaders_id = array();
			foreach ( $this->team_filter as $team_id ) {
				$permit_leaders_id_for_a_team = $MonLabo_access_data->get_leaders_id_for_a_team( $team_id );
				if ( NULL === $permit_leaders_id_for_a_team ) {
					$permit_leaders_id_for_a_team = array();
				}
				$permit_leaders_id = $permit_leaders_id + $permit_leaders_id_for_a_team;
			}
		}

		//Extraire les leaders du tableau initial
		if ( !empty( $this->persons_table ) ) {
			foreach ( $this->persons_table as $key => $person ) {
				if ( property_exists( $person, 'id' ) ) {
					//if the person is a leader
					if ( !empty( $this->team_filter ) ) {
						if ( in_array( $person->id, $permit_leaders_id ) ) {
							$table_of_leaders[$key] = $person;
						}
					} else {
						$teams_id_for_a_leader = $MonLabo_access_data->get_teams_id_for_a_leader( $person->id );
						if ( !empty( $teams_id_for_a_leader ) ) {
							$table_of_leaders[$key] = $person;
						}
					}
				}
			}
		}
		//Effacer les leaders du tableau initial
		if ( $suppress_leaders ) {
			if ( !empty( $table_of_leaders ) ) {
				foreach ( $table_of_leaders as $key => $dummy ) {
					unset( $this->persons_table[$key] );
				}
			}
		}
		return New MonLabo_persons( $table_of_leaders );
	}

	//--------------------------------------------------------------------------------
	// Trie un tableau de $persons_information par nom
	//--------------------------------------------------------------------------------
	public function sort_by_name() {
		$table_to_sort = array();
		if ( $this->count()>0 ) {
			foreach ( $this->persons_table as $key=>$person_info ) {
				if ( ( isset( $person_info->first_name ) ) and ( isset( $person_info->last_name ) ) ) {
					$table_to_sort["$person_info->last_name $person_info->first_name".$key ] = $person_info;
				}
			}
			ksort( $table_to_sort );
		}
		$this->persons_table = $table_to_sort;
		return $this;
	}


	//--------------------------------------------------------------------------------
	// Supprime les personnes qui ne sont pas dans l'une des catégories fournies en argument
	//--------------------------------------------------------------------------------
	public function filter_with_categories( $categories ) {
		if ( !empty( $this->persons_table ) ) {
			// supprime les personnes qui ne sont pas dans l'une des catégories fournies en argument
			if ( empty( $categories ) ) {
				//On supprime tout
				$this->persons_table = array();
				return $this;
			}

			$key_to_suppress = array();
			foreach ( $this->persons_table as $key => $person ) {
				if ( property_exists( $person, 'category' ) ) {
					if ( !in_array( $person->category, $categories ) ) {
						$key_to_suppress[$key] = $key;
					}
				}
			}
			if ( !empty( $key_to_suppress ) ) {
				foreach ( $key_to_suppress as $key => $dummy ) {
					unset( $this->persons_table[$key] );
				}
			}
		}
		return $this;
	}

	//--------------------------------------------------------------------------------
	// Supprime les personnes qui ne sont pas dans une liste fournie en argument
	//--------------------------------------------------------------------------------
	public function filter_with_ids( $persons_ids ) {
		if ( !empty( $this->persons_table ) ) {

			if ( empty( $persons_ids ) ) {
				//On supprime tout
				$this->persons_table = array();
				return $this;
			}

			//1 - On indexe pour suppression toute personne n'etant pas dans la liste autorisée
			$key_to_suppress = array();
			foreach ( $this->persons_table as $key => $person ) {
				if ( !in_array( $key, $persons_ids ) ) {
					$key_to_suppress[$key] = $key;
				}
			}

			//2 - On procède à la suppression effective
			if ( !empty( $key_to_suppress ) ) {
				foreach ( $key_to_suppress as $key => $dummy ) {
					unset( $this->persons_table[$key] );
				}
			}
		}
		return $this;
	}


	//--------------------------------------------------------------------------------
	// Supprime les personnes qui ne sont pas dans l'une des équipe fournies en argument
	//--------------------------------------------------------------------------------
	public function filter_with_teams( $teams, $status = 'actif' ) {
		if ( !empty( $this->persons_table ) ) {

			//0 - On met à jour la table de filtrage
			if ( empty( $this->team_filter ) ) {
				$this->team_filter = $teams;
			} else {
				$this->team_filter = array_intersect( $this->team_filter, $teams );
				$teams = $this->team_filter;
			}

			//1 - On établi une liste d'id de personnes qui seront autorisées
			$MonLabo_access_data = New MonLabo_access_data();
			$permit_person_ids = array();
			if ( empty( $teams ) ) {
				$this->persons_table = array();
				return $this;
			}
			foreach ( $teams as $team_id ) {
				$persons_for_a_team = $MonLabo_access_data->get_persons_id_for_a_team ( $team_id, $status );
				if ( NULL === $persons_for_a_team ) { $persons_for_a_team = Array(); }
				$permit_person_ids = $permit_person_ids + $persons_for_a_team;
			}

			//2 - On supprime toute personne n'etant pas dans la liste autorisée
			$this->filter_with_ids( $permit_person_ids );
		}
		return $this;
	}


	//--------------------------------------------------------------------------------
	// Supprime les personnes qui ne sont pas dans l'une des unités fournies en argument
	//--------------------------------------------------------------------------------
	public function filter_with_units( $units, $status = 'actif' ) {
		if ( !empty( $this->persons_table ) ) {
			//1 - On établi une liste d'id de personnes qui seront autorisées
			$MonLabo_access_data = New MonLabo_access_data();
			$teams = array();
			if ( empty( $units ) ) {
				$this->persons_table = array();
				$this->team_filter = array();
				return $this;
			} else {
			  foreach ( $units as $unit_id ) {
				  $teams_for_unit = $MonLabo_access_data->get_teams_id_for_an_unit( $unit_id );
				  if ( NULL === $teams_for_unit ) { $teams_for_unit = Array(); }
				  $teams = $teams + $teams_for_unit;
			  }
			}
			//2 - On supprime toute personne n'etant pas dans la liste autorisée
			$this->filter_with_teams( $teams, $status );
		}
		return $this;
	}

	//--------------------------------------------------------------------------------
	// Supprime les alumni qui ne sont pas partis dans la plage ou liste d'année indiquée
	//--------------------------------------------------------------------------------
	public function filter_with_alumni_years( $years ) {
		$MonLabo_access_data = New MonLabo_access_data();
		$permit_person_ids = array();
		if ( ( empty( $years ) ) or ( empty( $this->persons_table ) ) ) {
			//Ne pas traiter les cas évidents sans réponse
			$this->persons_table = array();
			return $this;
		}

		//1 - On établi une liste d'id de personnes qui seront autorisées
		$key_to_suppress = array();
		$years = str_replace( '|', ',', $years ); //Pouvoir utiliser | comme separateur
		$annees = explode( ',', $years ); // Annee can be a list 'year1|year2|year3....'
		if ( count( $annees ) >= 2 ) {
			//On va supprimer tous les alumni qui ne sont pas dans cette liste d'annee
			foreach ( $this->persons_table as $key => $person ) {
				if ( property_exists( $person, 'date_departure' ) ) {
					if ( !in_array( $person->date_departure, $annees ) ) {
						$key_to_suppress[$key] = $key;
					}
				}
			}
		} else {
			$annees = explode( '-', $years ); // Annee can be an interval 'year1-year2'
			if ( count( $annees ) < 2 ) {
				if ( is_array( $annees ) and ( isset( $annees[0] ) ) ) {
					$annees = $annees[0];
				}
				//On va supprimer tous les alumni qui ne sont pas à cette annee
				foreach ( $this->persons_table as $key => $person ) {
					if ( property_exists( $person, 'date_departure' ) ) {
						if ( $person->date_departure != intval( $annees ) ) {
							$key_to_suppress[$key] = $key;
						}
					}
				}
			} else {
				if ( '' === $annees[0] ) { // Annee can be an interval '-duration'
					$annees[0] = date( 'Y' ) - $annees[1]; //année en cours - durée
					$annees[1] = '9999';
				}
				//On va supprimer tous les alumni qui ne sont pas dans la plage d'annee
				foreach ( $this->persons_table as $key => $person ) {
					if ( property_exists( $person, 'date_departure' ) ) {
						if ( ( $person->date_departure < $annees[0] ) or  ( $person->date_departure > $annees[1] ) ) {
							$key_to_suppress[$key] = $key;
						}
					}
				}
			}
		}
		//Supprimer les alumni repérés mauvais
		if ( !empty( $key_to_suppress ) ) {
			foreach ( $key_to_suppress as $key => $dummy ) {
				unset( $this->persons_table[$key] );
			}
		}
		return $this;
	}

}
