<?php
//error_reporting( E_ALL );
//ini_set( 'display_errors',1 );
defined( 'ABSPATH' ) or die( 'No direct script access allowed' );

require_once( dirname( __FILE__ ) . '/MonLabo-shortcodes.php' );
require_once( dirname( __FILE__ ) . '/MonLabo-translate.php' );

/**
 * Class MonLabo_shortcodes_publications
 *
 * @package
 */

class MonLabo_shortcodes_publications extends MonLabo_shortcodes_mother_class {
	/*
		static function suppress_bibtex_value_limiter( $string )

		static function custom_publications_list				( $atts )
		static function custom_publications_list_web			( $atts, $webservice_class_name = 'MonLabo_contact_webservices' )
		static function custom_publications_list_preprare_url   ( $atts )

		static function publications_list				   ( $atts )
		static function publications_list_web			   ( $atts,  $webservice_class_name = 'MonLabo_contact_webservices' )
		static function publications_list_prepare_url	   ( $years, $units = '', $teams = '' )

		static function parse_haltools_response ( $hal_content = '' )
		static function format_publi			( $format = 'ieee', $data_publi, $currentlang )
		static function bibtex_to_ieee_authors  ( $authors_bib_string )
		static function bibtex_to_apa_authors   ( $authors_bib_string )
		static function format_bib_field		( $array, $field, $format )

	*/

	private static function _MonLaboPersonsIds_into_publicationServerAuthorsIds( $persons_id, $base_to_use='hal' ) {
		return self::_MonLabo__item__ids_into_publicationServer__item__ids( $persons_id, 'person', $base_to_use );
	}

	private static function _MonLaboTeamsIds_into_publicationServerTeamsIds( $teams_id, $base_to_use='hal' ) {
		return self::_MonLabo__item__ids_into_publicationServer__item__ids( $teams_id, 'team', $base_to_use );
	}

	private static function _MonLaboUnitsIds_into_publicationServerUnitsIds( $units_id, $base_to_use='hal' ) {
		return self::_MonLabo__item__ids_into_publicationServer__item__ids( $units_id, 'unit', $base_to_use );
	}

	private static function _MonLabo__item__ids_into_publicationServer__item__ids( $items_id, $type_of_item, $base_to_use ) {
		$publication_database_ids = array();
		if ( !empty( $items_id ) ) {
			$prefix = '';
			if ( 'DescartesPubli' === $base_to_use ) {
				$prefix = 'descartes_publi_';
			} elseif ( 'hal' === $base_to_use ) {
				$prefix = 'hal_publi_';
			}
			$field_name = '';
			switch ( $type_of_item ) {
				case 'person':
					$field_name = $prefix . 'author_id';
					$get_item_information_function_name = 'get_person_information';
					break;
				case 'team':
					$field_name = $prefix . 'team_id';
					$get_item_information_function_name = 'get_team_information';
					break;
				case 'unit':
					$field_name = $prefix . 'unit_id';
					$get_item_information_function_name = 'get_unit_information';
					break;
			}
			if ( !empty( $field_name ) ) {
				$MonLabo_access_data = New MonLabo_access_data();
				foreach ( $items_id as $item_id ) {
					$the_item = $MonLabo_access_data->$get_item_information_function_name( $item_id );
					if ( ( !empty( $the_item ) ) and ( !empty( $the_item->$field_name ) ) ) {
						$publication_database_ids = array_merge( $publication_database_ids, MonLaboLib::prepare_multiple_values_variable_into_array( $the_item->$field_name ) );
					}
				}
			}
		}
		return array_unique( $publication_database_ids );
	}

	//==========================================================================
	/**
	 * Supprimer les carractères entourant une chaine parmis les carractères
	 * quotes, doubles quotes, accolades ou doubles accolades.
	 * @param string $string Chaine à traiter
	 * @return string Chaine traitée
	 */
	//==========================================================================
	static function suppress_bibtex_value_limiter( $string ) {
		$string = trim( $string );
		$size = strlen( $string )-1;
		if ( $size>0 ) {
			if ( $string[0] === $string[$size] ) {
				if ( ( '"' === $string[0] ) or ( "'" === $string[0] ) ) {
					$string = substr( $string, 1, -1 );  //Si "chaine" ou 'chaine'
				}
			} elseif ( ( '{' === $string[0] ) and ( '}' === $string[$size] ) ) {
				if ( $size>3 ) {
					if ( ( '{' === $string[1] ) and ( '}' === $string[$size-1] ) ) {
						$string = substr( $string, 1, -1 ); //Si {{chaine}}
					}
				}
				$string = substr( $string, 1, -1 ); //Si {chaine} ou {{chaine}}
			}
		}
		return trim( $string );
	}

	static function build_HAL_POST_query( $years, $languageHAL, $style_citation_reference ) {
		$POST_query = array();

		//Calcul des paramètres des années
		//--------------------------------
		if ( strlen( $years )>0 ) {
			$anneeMinAndMax = explode( '-', $years );
			$anneeMin = $anneeMinAndMax[0];
			if ( count( $anneeMinAndMax )>1 ) {
				$anneeMax = $anneeMinAndMax[1];
			} else {
				$anneeMax = $anneeMinAndMax[0];
			}
			if ( !empty( $anneeMin ) ) {
				$POST_query['annee_publideb'] = "$anneeMin";
				if ( !empty( $anneeMax ) ) {
					$POST_query['annee_publifin'] = "$anneeMax";
				}
			} else {
				if ( !empty( $anneeMax ) ) {
					$POST_query['annee_publifin'] = "$anneeMax";
				}
			}
		}

		//Calcul des autres paramètres de requête
		//---------------------------------------
		$POST_query['tri_exp'] = 'typdoc';
		$POST_query['tri_exp2'] = 'annee_publi';
		$POST_query['tri_exp3'] = 'auteur_exp';
		if ( strcmp( $style_citation_reference, 'hal' ) === 0 ) {
			$POST_query['CB_ref_biblio'] = 'oui';
			$POST_query['ordre_aff'] = 'TA';
			$POST_query['Fen'] = 'Aff';
			$POST_query['langue'] = $languageHAL;
			$api_base_url = 'https://haltools.archives-ouvertes.fr/Public/afficheRequetePubli.php?';
			$request_mode = 'native_html_display';
		} else {
			$POST_query['CB_accent_latex'] = 'non';
			$POST_query['format_export'] = 'bibtex';
			$POST_query['langue'] = 'Anglais';
			$api_base_url = 'https://haltools.inria.fr/Public/exportPubli.php?';
			$request_mode = 'generate_html_from_bibtext';
		}
		return array( $api_base_url, $POST_query, $request_mode );
	}

	////////////////////////////////////////////////////////////////////////////////
	// A EFFACER DANS V3.0
	////////////////////////////////////////////////////////////////////////////////
	//==========================================================================
	/**
	 * partie non testable du Shortcode [custom_publications_list]
	 * @param array $atts tableau de paramètres du shortcode
	 * @return string URL de la page a web de la requête vers la base de publication
	 */
	//==========================================================================
	static function custom_publications_list( $atts ) {
		// @codeCoverageIgnoreStart
		return self::custom_publications_list_web( $atts );
		// @codeCoverageIgnoreEnd
	}
	////////////////////////////////////////////////////////////////////////////////

	////////////////////////////////////////////////////////////////////////////////
	// A EFFACER DANS V3.0
	////////////////////////////////////////////////////////////////////////////////
	//==========================================================================
	/**
	 * partie testable du Shortcode [custom_publications_list]
	 * @param array $atts tableau de paramètres du shortcode
	 * @param string $webservice_class_name nom de la classe qui sera utilisée pour faire la requête CURL
	 *									  ( permet de substituer un CURL par une fonction bouchon en test unitaire )
	 * @return string Code HTML généré par la requête
	 */
	//==========================================================================
	static function custom_publications_list_web( $atts, $webservice_class_name = 'MonLabo_contact_webservices' ) {
		$url = self::custom_publications_list_preprare_url( $atts );
		$webservice_class_instance = New $webservice_class_name();
		return ( empty( $url ) ? '' : $webservice_class_instance->webpage_get_content( $url ) );
	}
	////////////////////////////////////////////////////////////////////////////////

	////////////////////////////////////////////////////////////////////////////////
	// A EFFACER DANS V3.0
	////////////////////////////////////////////////////////////////////////////////
	//==========================================================================
	/**
	 * générateur de requête URL du Shortcode [custom_publications_list]
	 * @param array $atts tableau de paramètres du shortcode
	 * @return string URL de la page a web de la requête vers la base de publication
	 */
	//==========================================================================
	static function custom_publications_list_preprare_url( $atts ) {
		$MonLabo_access_data = New MonLabo_access_data();

		$options0 = get_option( 'MonLabo_settings_group0' );
		$options4 = get_option( 'MonLabo_settings_group4' );

		// normalize attribute keys, lowercase
		$atts = array_change_key_case( (array) $atts, CASE_LOWER );

		// Get the parameters and set default values
		$args = shortcode_atts(
			array(
				'alias' => '__empty__',
				'unite' => '__empty__',
				'equipe' => '__empty__',
				'years' => '',
				'year' => '',
				'annee' => '',
				'limit' => '',
				'offset' => '',
				'debug' => '__empty__',
				'type' => '__empty__',
				'auteurid' => '__empty__',
				'lang' => '',
				'nohighlight' => '__empty__',
				'displaytype' => '__empty__',
				'format' => '__empty__',
				'idhal' => '__empty__',
				'struct' => '__empty__',
			),
			$atts,
			'custom_publications_list'
		);

		//Normalize values keys
		$args['debug'] = sanitize_key( $args['debug'] );
		$args['type'] = strtolower( sanitize_text_field( $args['type'] ) );
		$args['lang'] = sanitize_key( $args['lang'] );
		$args['nohighlight'] = sanitize_key( $args['nohighlight'] );
		$args['displaytype'] = sanitize_key( $args['displaytype'] );
		$args['format'] = sanitize_key( $args['format'] );
		$args['alias'] = sanitize_text_field( $args['alias'] );
		$args['unite'] = sanitize_text_field( $args['unite'] );
		$args['equipe'] = sanitize_text_field( $args['equipe'] );
		if ( !( '' === $args['offset'] ) ) { $args['offset'] = intval( $args['offset'] ); }
		if ( !( '' === $args['limit'] ) ) { $args['limit'] = intval( $args['limit'] ); }
		$args['idhal'] = sanitize_text_field( $args['idhal'] );
		$args['struct'] = sanitize_text_field( $args['struct'] );

		// Pouvoir utiliser le paramètre years au sigulier au besoin
		if ( '' === $args['years'] ) { $args['years'] = $args['year'];	}
		// Par defaut years remplace annee sauf si years est vide
		if ( '' === $args['years'] ) { $args['years'] = $args['annee'];	}
		$args['years'] = sanitize_text_field( $args['years'] );

		// Build url from parameters
		$POST_query = array();

		$url = '';
		$DESCARTES_custom_parameters=array();
		$HAL_custom_parameters=array();

		//Pour des publications Descartes Publi
		//-------------------------------------
		if ( 'DescartesPubli' === $options0['MonLabo_publication_server_type'] ) {

			//On change les valeurs par défaut de [publications_list]
			switch ( $args['displaytype'] ) {
				case 'with_titles':
					$orga_types = 'par_titre';
					break;
				case 'for_each':
					$orga_types = 'par_publication';
					break;
				default:
					$orga_types = 'aucun';
					break;
			}
			if ( '__empty__' === $args['type'] ) {
				$args['type'] = 'pub_journaux';
			}

			$DESCARTES_custom_parameters = array(
				'descartes_alias'		=> $args['alias'],
				'descartes_auteurid' 	=> $args['auteurid'],
				'descartes_equipe'		=> $args['equipe'],
				'descartes_unite'		=> $args['unite'],
				'descartes_typepub' 	=> $args['type'],
				'descartes_nohighlight'	=> $args['nohighlight'],
				'descartes_orga_types' 	=> $orga_types,
				'descartes_format'		=> $args['format'],
				'descartes_debug'		=> $args['debug']
			);
		//Pour des publications HAL
		//-------------------------
		} elseif ( 'hal' === $options0['MonLabo_publication_server_type'] ) {
			$HAL_custom_parameters = array (
				'hal_struct'=>$args['struct'],
				'hal_idhal'=>$args['idhal']
			);
		}

		list( $request_mode, $url ) = self::publications_list_prepare_url(
			$args['years'],
			'' /*no units*/,
			'' /*no teams*/,
			'' /*no persons*/,
			$args['lang'],
			$args['limit'],
			$args['offset'],
			$HAL_custom_parameters,
			$DESCARTES_custom_parameters
		);
		return $url;
	}
	////////////////////////////////////////////////////////////////////////////////

	//==========================================================================
	/**
	 * partie non testable du Shortcode [publications_list]
	 * @param array $atts tableau de paramètres du shortcode
	 * @return string URL de la page a web de la requête vers la base de
	 *                publication
	 */
	//==========================================================================
	static function publications_list( $atts ) {
		// @codeCoverageIgnoreStart
		return self::publications_list_web( $atts );
		// @codeCoverageIgnoreEnd
	}

	//==========================================================================
	/**
	 * partie testable du Shortcode [publications_list]
	 * @param array $atts tableau de paramètres du shortcode
	 * @param string $webservice_class_name nom de la classe qui sera utilisée
	 *               pour faire la requête CURL ( permet de substituer un CURL
	 *               par une fonction bouchon en test unitaire )
	 * @return string Code HTML généré par la requête
	 */
	//==========================================================================
	static function publications_list_web( $atts,  $webservice_class_name = 'MonLabo_contact_webservices' ) {
		// 0 - Initialisations
		//--------------------
		$publications = '';
		$a_afficher = '';
		$options0 = get_option( 'MonLabo_settings_group0' );
		$options4 = get_option( 'MonLabo_settings_group4' );
		$style_citation_reference = $options4['MonLabo_hal_publi_style'];
		$currentlang = get_bloginfo( 'language' );
		$webservice_class_instance = New $webservice_class_name();

		// 1 - Récupération des paramètres et valeurs par défaut
		//------------------------------------------------------

		// normalize attribute keys, lowercase
		$atts = array_change_key_case( (array) $atts, CASE_LOWER );

		// get parameters
		$args = shortcode_atts(
			array(
				'title' => '__empty__',			   //Optional title
				'titre' => '__empty__',
				'annee' => '',
				'year' => '',
				'years' => '',
				'units' => '',
				'unit' => '',
				'teams' => '',
				'team' => '',
				'persons' => '',
				'person' => '',
				'lang' => '__empty__',
				'limit' => '',
				'offset' => '',
				'hal_struct' =>  '__empty__',
				'hal_idhal' =>  '__empty__',
				'descartes_alias' =>  '__empty__',
				'descartes_auteurid' =>  '__empty__',
				'descartes_unite' =>  '__empty__',
				'descartes_equipe' =>  '__empty__',
				'descartes_typepub' =>  '__empty__',
				'descartes_nohighlight' =>  '__empty__',
				'descartes_orga_types' =>  '__empty__',
				'descartes_format' =>  '__empty__',
				'descartes_debug' =>  '__empty__',
				'base' => '',
			),
			$atts,
			'publications_list'
		);

		// Curation des paramètres homonymes, surnuméraires ou incompatibles
		// -----------------------------------------------------------------
		$args['lang'] = sanitize_key( $args['lang'] );
		$args['descartes_debug'] = sanitize_key( $args['descartes_debug'] );
		$args['descartes_nohighlight'] = sanitize_key( $args['descartes_nohighlight'] );
		$args['descartes_orga_types'] = sanitize_key( $args['descartes_orga_types'] );
		$args['descartes_format'] = sanitize_key( $args['descartes_format'] );
		$args['descartes_alias'] = sanitize_text_field( $args['descartes_alias'] );
		$args['descartes_typepub'] = sanitize_text_field( $args['descartes_typepub'] );
		$args['descartes_auteurid'] = sanitize_text_field( $args['descartes_auteurid'] );
		$args['descartes_unite'] = sanitize_text_field( $args['descartes_unite'] );
		$args['descartes_equipe'] = sanitize_text_field( $args['descartes_equipe'] );
		if ( !( '' === $args['offset'] ) ) { $args['offset'] = intval( $args['offset'] ); }
		if ( !( '' === $args['limit'] ) ) { $args['limit'] = intval( $args['limit'] ); }
		$args['hal_idhal'] = sanitize_text_field( $args['hal_idhal'] );
		$args['hal_struct'] = sanitize_text_field( $args['hal_struct'] );
		$args['base'] = sanitize_text_field( $args['base'] );

		// Pouvoir utiliser le paramètre years au sigulier au besoin
		if ( '' === $args['years'] ) { $args['years'] = $args['year'];	}
		// Par defaut years remplace annee sauf si years est vide
		if ( '' === $args['years'] ) { $args['years'] = $args['annee'];	}
		$args['years'] = sanitize_text_field( $args['years'] );

		// Pouvoir utiliser le paramètre $args['persons'] au sigulier au besoin
		if ( '' === $args['persons'] ) { $args['persons'] = $args['person'];  }
		$args['persons'] = sanitize_text_field( $args['persons'] );

		// Pouvoir utiliser le paramètre teams au sigulier au besoin
		if ( '' === $args['teams'] )   { $args['teams'] = $args['team'];	  }
		$args['teams'] = sanitize_text_field( $args['teams'] );

		// Pouvoir utiliser le paramètre units au sigulier au besoin
		if ( '' === $args['units'] )   { $args['units'] = $args['unit'];	  }
		$args['units'] = sanitize_text_field( $args['units'] );

		// Pouvoir utiliser le paramètre title en français ou anglais
		if ( '__empty__' === $args['title'] )   { $args['title'] = $args['titre'];	 }
		$args['title'] = sanitize_text_field( $args['title'] );

		//Pouvoir utiliser le paramètre years au sigulier au besoin
		if ( '' === $args['years'] )   { $args['years'] = $args['year'];	  }
		// Pouvoir utiliser le paramètre annee en français ou anglais
		if ( '' === $args['years'] )   { $args['years'] = $args['annee'];	 }

		// Pouvoir forcer la langue
		if ( '__empty__' === $args['lang'] )   { $args['lang'] = $currentlang;	 }

		// Valeur par défaut du paramètre titre
		if ( ( 'DescartesPubli' === $options0['MonLabo_publication_server_type'] )
				or ( ( 'both' === $options0['MonLabo_publication_server_type'] )
					and ( 'descartespubli' === $args['base'] )
				)
			) {
			if ( strcmp ( $args['title'], '__empty__' ) === 0 ) {
				$args['title'] = MonLabo_translate::translate( 'Recent Publications', $args['lang'] );
			}
		}

		// 2 - On forge l'URL et demande le mode de traitement de cette URL
		// ----------------------------------------------------------------
		$HAL_custom_parameters = array(
			'HALstruct'=>$args['hal_struct'],
			'hal_idhal' => $args['hal_idhal']
		);
		$DESCARTES_custom_parameters = array(
			'descartes_alias'		=> $args['descartes_alias'],
			'descartes_auteurid' 	=> $args['descartes_auteurid'],
			'descartes_unite'		=> $args['descartes_unite'],
			'descartes_equipe'		=> $args['descartes_equipe'],
			'descartes_typepub' 	=> $args['descartes_typepub'],
			'descartes_nohighlight'	=> $args['descartes_nohighlight'],
			'descartes_orga_types' 	=> $args['descartes_orga_types'],
			'descartes_format'		=> $args['descartes_format'],
			'descartes_debug'		=> $args['descartes_debug']
		);
		list( $request_mode, $url ) = self::publications_list_prepare_url(
			$args['years'],
			$args['units'],
			$args['teams'],
			$args['persons'],
			$args['lang'],
			$args['limit'],
			$args['offset'],
			$HAL_custom_parameters,
			$DESCARTES_custom_parameters,
			$args['base']
		);

		// 3 - Traitement de l'URL
		//------------------------
		switch ( $request_mode ) {
			case 'native_html_display':
				$contenu = $webservice_class_instance->webpage_get_content( $url );
				//Aller chercher le code au sein des balises <body></body> si elles existent
				if ( !empty( $contenu ) ) {
					$contenu_explose = explode ( '<body>', $contenu );
					if ( count( $contenu_explose )>1 ) {
						$contenu_explose = explode ( '</body>', $contenu_explose[1] );
					}
					$publications = $contenu_explose[0];
				} else {
					$publications = '';
				}
				break;

			case 'generate_html_from_bibtext':
				$hal_content = $webservice_class_instance->webpage_get_content( $url );
				$publi = self::parse_haltools_response( $hal_content );
				$publications = self::format_publi( $style_citation_reference, $publi, $args['lang'] );
				break;

			default:
				$publications = '';
				break;
		}

		// 4 - affichage des publications
		//-------------------------------
		if ( strlen( $publications )>10 ) {
			//Un titre avec '__empty__' doit être vide
			if ( ( !empty( $args['title'] ) ) and ( 0 != strcmp ( $args['title'], '__empty__' ) ) ) {
				$a_afficher .= '<h1>'.$args['title'].'</h1>';
			}
			$a_afficher .= $publications;
		}

		return $a_afficher;
	}

	///////////////////////////////////////////////////////////////////////////////////////////

	//==========================================================================
	/**
	* générateur de requête URL du Shortcode [publications_list]
	 * @param string $years
	 * @param string $units
	 * @param string $teams
	 * @param string $lang
	 * @param string $limit
	 * @param string $offset
	 * @return string URL de la page a web de la requête vers la base de publication
	 */
	//==========================================================================
	static function publications_list_prepare_url(
		$years,
		$units = '',
		$teams = '',
		$persons = '',
		$lang = '',
		$limit = '' ,
		$offset = '',
		$HAL_custom_parameters = null,
		$DESCARTES_custom_parameters = null,
		$base = ''
	) {
		$MonLabo_access_data = New MonLabo_access_data();
		$POST_query = array();


		//Récupération des paramètres HAL
		$hal_struct = '__empty__';
		if ( isset( $HAL_custom_parameters['hal_struct'] ) ) {
			$hal_struct = $HAL_custom_parameters['hal_struct'];
		}
		$hal_idhal = '__empty__';
		if ( isset( $HAL_custom_parameters['hal_idhal'] ) ) {
			$hal_idhal = $HAL_custom_parameters['hal_idhal'];
		}
		//Récupération des paramètres DESCARTES
		$descartes_alias = '__empty__';
		if ( isset( $DESCARTES_custom_parameters['descartes_alias'] ) ) {
			 $descartes_alias = $DESCARTES_custom_parameters['descartes_alias'];
		 }
		$descartes_auteurid = '__empty__';
		if ( isset( $DESCARTES_custom_parameters['descartes_auteurid'] ) ) {
			$descartes_auteurid = $DESCARTES_custom_parameters['descartes_auteurid'];
		}
		$descartes_equipe = '__empty__';
		if ( isset( $DESCARTES_custom_parameters['descartes_equipe'] ) ) {
			$descartes_equipe = $DESCARTES_custom_parameters['descartes_equipe'];
		}
		$descartes_unite = '__empty__';
		if ( isset( $DESCARTES_custom_parameters['descartes_unite'] ) ) {
			$descartes_unite = $DESCARTES_custom_parameters['descartes_unite'];
		}
		$descartes_typepub = '__empty__';
		if ( isset( $DESCARTES_custom_parameters['descartes_typepub'] ) ) {
			$descartes_typepub = $DESCARTES_custom_parameters['descartes_typepub'];
		}
		$descartes_nohighlight = '__empty__';
		if ( isset( $DESCARTES_custom_parameters['descartes_nohighlight'] ) ) {
			$descartes_nohighlight = $DESCARTES_custom_parameters['descartes_nohighlight'];
		}
		$descartes_orga_types = '__empty__';
		if ( isset( $DESCARTES_custom_parameters['descartes_orga_types'] ) ) {
			$descartes_orga_types = $DESCARTES_custom_parameters['descartes_orga_types'];
		}
		$descartes_format = '__empty__';
		if ( isset( $DESCARTES_custom_parameters['descartes_format'] ) ) {
			$descartes_format = $DESCARTES_custom_parameters['descartes_format'];
		}
		$descartes_debug = '__empty__';
		if ( isset( $DESCARTES_custom_parameters['descartes_debug'] ) ) {
			$descartes_debug = $DESCARTES_custom_parameters['descartes_debug'];
		}

		// Les valeur descartes_custom viennent écraser les autres
		if (
			   ( '__empty__' != $descartes_alias )
			or ( '__empty__' != $descartes_auteurid )
			or ( '__empty__' != $descartes_equipe )
			or ( '__empty__' != $descartes_unite )
		) {
			$units = ''; $teams = ''; $persons = '';
		}

		//-----------------------------
		// 1 - Récupération des options
		//-----------------------------
		$options0 = get_option( 'MonLabo_settings_group0' );
		$options1 = get_option( 'MonLabo_settings_group1' );
		$options4 = get_option( 'MonLabo_settings_group4' );
		$style_citation_reference = $options4['MonLabo_hal_publi_style'];

		$base_to_use='';
		/*                       +------------------------------------------------+
		    valeur de            |  $options0['MonLabo_publication_server_type']  |
		    $base_to_use         +----------------+-------+----------------+------+
		                         | DescartesPubli |  hal  |     both       |  ''  |
		+-------+----------------+----------------+-------+----------------+------+
		|       |       ''       | DescartesPubli    hal        hal           ''  |
		|       +----------------+                                                +
		| $base | descartespubli | DescartesPubli    hal    DescartesPubli    ''  |
		|       +----------------+                                                +
		|       |      hal       | DescartesPubli    hal        hal           ''  |
		+-------+----------------+----------------+-------+----------------+------+*/
		if ( ( 'DescartesPubli' === $options0['MonLabo_publication_server_type'] )
				or ( ( 'both' === $options0['MonLabo_publication_server_type'] )
					and ( 'descartespubli' === $base )
				)
			) {
			$base_to_use = 'DescartesPubli';
		} elseif ( ( 'hal' === $options0['MonLabo_publication_server_type'] )
					or ( ( 'both' === $options0['MonLabo_publication_server_type'] )
						and ( 'descartespubli' != $base )
					)
				) {
			$base_to_use = 'hal';
		}

		if ( 'DescartesPubli' === $base_to_use ) {
			$descartes_format_in_options = $options4['MonLabo_DescartesPubmed_format'];
		}
		$request_mode = '';
		$request = '';

		//-------------------------------
		// 2 - Détermination de la langue
		//-------------------------------
		if ( empty( $lang ) ) {
			switch ( get_bloginfo( 'language' ) ) {
				case 'en-US':
				case 'en-GB':
					$languageHAL = 'Anglais';
					$languageShortcode = 'en';
					break;
				default: //'fr-FR'
					$languageHAL = 'Francais';
					$languageShortcode = 'fr';
			}
		} else { //La langue est forcée
			switch ( $lang ) {
				case 'en-US':
				case 'en-GB':
				case 'en':
				case 'anglais':
				case 'english':
				case 'Anglais':
					$languageHAL = 'Anglais';
					$languageShortcode = 'en';
					break;
				default: //'fr-FR'
					$languageHAL = 'Francais';
					$languageShortcode = 'fr';
			}
		}

		//-------------------------------------
		// 3 - Si persons, teams ou units = '*'
		//-------------------------------------
		if ( '*' === $persons ) {
			$all_persons_id = array_keys( $MonLabo_access_data->get_persons_information() );
			if ( !empty( $all_persons_id ) ) { $persons = implode( '|', $all_persons_id ); }
		}
		if ( '*' === $teams ) {
			$all_teams_id = array_keys( $MonLabo_access_data->get_teams_information() );
			if ( !empty( $all_teams_id ) ) { $teams = implode( '|', $all_teams_id ); }
		}
		if ( '*' === $units ) {
			$all_units_id = array_keys( $MonLabo_access_data->get_units_information() );
			if ( !empty( $all_units_id ) ) { $units = implode( '|', $all_units_id ); }
		}

		//----------------------------------
		// 4 - Détermination du type de page
		//----------------------------------
		$persons_id = array();
		$teams_id = array();
		$units_id = array();
		if ( ( '' === $teams ) and ( '' === $units ) and ( '' === $persons ) ) {
			//Déterminer a qui apartient la page courante
			$persons = self::_person_of_curent_page();
			$page_mode = 'user_page';
			if ( empty( $persons ) ) {
				$teams = self::_team_of_curent_page();
				$page_mode = 'team_or_unit_page';
				if ( empty( $teams ) ) {
					$units = self::_unit_of_curent_page();
					if ( empty( $units ) ) {
						$page_mode = 'main_structure_page';
					}
				}
			}
		} else {
		  if ( empty( $persons ) ) {
			$page_mode = 'team_or_unit_page';
		  } else {
			$page_mode = 'user_page';
		  }
		}
		//Mise en tableau
		$teams_id	  = MonLaboLib::prepare_multiple_values_variable_into_array( $teams );
		$units_id	  = MonLaboLib::prepare_multiple_values_variable_into_array( $units );
		$persons_id	= MonLaboLib::prepare_multiple_values_variable_into_array( $persons );

		//----------------------------------------------------------------
		// 5.1 Traitement si le serveur de publication est Paris Descartes
		//----------------------------------------------------------------
		if ( 'DescartesPubli' === $base_to_use ) {
			$request_mode = 'native_html_display';
			$api_base_url = $options4['MonLabo_DescartesPubmed_api_url'].'?';

			//Paramètres communs
			$POST_query['lang'] = "$languageShortcode";
			$POST_query['type'] = '*';
			$POST_query['orga_types'] = 'par_titre';
			$POST_query['format'] = "$descartes_format_in_options";
			if ( strlen( $years )>0 ) {
				$POST_query['annee'] = "$years";
			}
			if ( !('' === $limit) ) {
				$POST_query['limit'] = intval( $limit );
			}
			if ( !('' === $offset) ) {
				$POST_query['offset'] = intval( $offset );
			}

			//On ecrase les autres paramètres avec les paramètres experts
			$expert_mode = false;
			if ( '__empty__' != $descartes_alias ) {
				$POST_query['alias'] = $descartes_alias;
				$expert_mode = true;
			}
			if ( '__empty__' != $descartes_auteurid ) {
				$POST_query['auteurid'] = $descartes_auteurid;
				$expert_mode = true;
			}
			if ( '__empty__' != $descartes_equipe ) {
				if ( '*' === $descartes_equipe ) {  //Get all the descartes_publi_team_id list of teams configured in MonLabo
					$all_teams_id = array_keys( $MonLabo_access_data->get_teams_information() );
					$descartes_team_ids   = self::_MonLaboTeamsIds_into_publicationServerTeamsIds( $all_teams_id, $base_to_use );
					if ( !empty( $descartes_team_ids ) ) { $descartes_equipe = implode( '|', $descartes_team_ids ); }
				}
				$POST_query['equipe'] = $descartes_equipe;
				$expert_mode = true;
			}
			if ( '__empty__' != $descartes_unite ) {
				$POST_query['unite'] = $descartes_unite;
				$expert_mode = true;
			}
			if ( '__empty__' != $descartes_typepub ) { //Ce paramètre expert est compatible avec les autres
				$POST_query['type'] = $descartes_typepub;
			}
			if ( '__empty__' != $descartes_nohighlight ) { //Ce paramètre expert est compatible avec les autres
				$POST_query['nohighlight'] = $descartes_nohighlight;
			}
			if ( '__empty__' != $descartes_orga_types ) { //Ce paramètre expert est compatible avec les autres
				$POST_query['orga_types'] = $descartes_orga_types;
			}
			if ( '__empty__' != $descartes_format ) { //Ce paramètre expert est compatible avec les autres
				$POST_query['format'] = $descartes_format;
			}
			if ( '__empty__' != $descartes_debug ) { //Ce paramètre expert est compatible avec les autres
				$POST_query['debug'] = $descartes_debug;
			}

			if ( false === $expert_mode ) {
				//En cas d'absence de paramètres experts
				if ( 'team_or_unit_page' === $page_mode ) {
					//Formatage de la requête
					$descartes_team_ids   = self::_MonLaboTeamsIds_into_publicationServerTeamsIds( $teams_id, $base_to_use );
					$descartes_unit_ids   = self::_MonLaboUnitsIds_into_publicationServerUnitsIds( $units_id, $base_to_use );
					if ( !empty( $descartes_team_ids ) ) {
						$POST_query['equipe'] = implode( '|', $descartes_team_ids );
					}
					if ( !empty( $descartes_unit_ids ) ) {
						$POST_query['unite'] = implode( '|', $descartes_unit_ids );
					}
					if ( ( !empty( $descartes_team_ids ) ) or ( !empty( $descartes_unit_ids ) ) ) {
						if ( strlen( $years ) === 0 ) {
							$POST_query['annee'] = '-5'; //Par défaut prendre les 5 dernières années
						}
					} else {
						//Page d'équipe ou d'unite, mais n'indique pas d'ID Descartes
						return array( '', '' ); /*Vide*/
					}
				} elseif ( 'user_page' === $page_mode ) {
					$descartes_ids = self::_MonLaboPersonsIds_into_publicationServerAuthorsIds( $persons_id, $base_to_use );
					if ( !empty( $descartes_ids ) ) {
						$POST_query['auteurid'] = implode( '|', $descartes_ids );
					} else {
						return array( '', '' ); /*Vide*/
					}
				} elseif ( 'main_structure_page' === $page_mode ) {
					//On retourne les publications de toutes les personnes
					$persons = '';
					$all_persons_id = array_keys( $MonLabo_access_data->get_persons_information() );
					if ( !empty( $all_persons_id ) ) { $persons = implode( '|', $all_persons_id ); }
					$persons_id	= MonLaboLib::prepare_multiple_values_variable_into_array( $persons );
					$descartes_ids = self::_MonLaboPersonsIds_into_publicationServerAuthorsIds( $persons_id, $base_to_use );
					if ( !empty( $descartes_ids ) ) {
						$POST_query['auteurid'] = implode( '|', $descartes_ids );
					} else {
						return array( '', '' ); /*Vide*/
					}
				} else {
					return array( '', '' ); /*Vide*/
				}
			}
		//----------------------------------------------------
		// 5.2 Traitement si le serveur de publication est HAL
		//----------------------------------------------------
		} elseif ( 'hal' === $base_to_use ) {

			//Construction de la la requête de base
			//-------------------------------------
			list( $api_base_url, $POST_query, $request_mode ) = self::build_HAL_POST_query( $years, $languageHAL, $style_citation_reference );

			//Calcul du paramètre identifiant l'équipe, la personne ou la structure
			//---------------------------------------------------------------------
			$HAL_ids = array();
			$idHal = array();

			//On ecrase les autres paramètres avec les paramètres experts
			if ( '__empty__' != $hal_idhal ) {
				$idHal= MonLaboLib::prepare_multiple_values_variable_into_array( $hal_idhal );
			} elseif ( '__empty__' != $hal_struct ) {
				$HAL_ids = MonLaboLib::prepare_multiple_values_variable_into_array( $hal_struct );
			} else {
				//En cas d'absence de paramètres experts
				if ( 'user_page' === $page_mode ) { //Personne
						$idHal = self::_MonLaboPersonsIds_into_publicationServerAuthorsIds( $persons_id, $base_to_use );
				} else {

					//Determine la liste des ID HAL a utiliser
					if ( 'team_or_unit_page' === $page_mode ) { //Equipe

						$HAL_ids =					   self::_MonLaboTeamsIds_into_publicationServerTeamsIds( $teams_id, $base_to_use );
						// Si pas de hal_publi_team_id définis pour les équipes
						if ( ( !empty( $teams_id ) ) and ( empty( $HAL_ids ) ) ) {
							//Retourner les publications des membres de l'équipe
							foreach ( $teams_id as $team_id ) {
								$idHal = array_merge( $idHal, self::_MonLaboPersonsIds_into_publicationServerAuthorsIds( $MonLabo_access_data->get_persons_id_for_a_team( $team_id ), $base_to_use ) );
							}
						}
						$unitHAL_ids = self::_MonLaboUnitsIds_into_publicationServerUnitsIds( $units_id, $base_to_use );
						$HAL_ids = array_merge( $HAL_ids, $unitHAL_ids );

						// Si pas de hal_publi_team_id définis pour les unités
						if ( ( !empty( $units_id ) ) and ( empty( $unitHAL_ids ) ) ) {
							//Retourner les publications des membres de l'unité
							foreach ( $units_id as $unit_id ) {
								$idHal = array_merge( $idHal, self::_MonLaboPersonsIds_into_publicationServerAuthorsIds( array_keys( $MonLabo_access_data->get_persons_information_for_an_unit( $unit_id ) ), $base_to_use ) );
							}
						}
					} elseif ( 'main_structure_page' === $page_mode ) {
						if ( !empty( $options1['MonLabo_hal_publi_struct_id'] ) ) {
							$HAL_ids = MonLaboLib::prepare_multiple_values_variable_into_array( $options1['MonLabo_hal_publi_struct_id'] );
						}
					}
					//Nettoyage des ID HAL non numériques
					if ( !empty( $HAL_ids ) ) {
						foreach ( $HAL_ids as $key => $value ) {
							if ( !is_numeric( $value ) ) {
								unset( $HAL_ids[$key] );
							}
						}
					}
				}
			}
			if ( !( '' === $limit ) ) {
				$POST_query['NbAffiche'] = intval( $limit );
			}
			//Les paramètres idHal et struct sont incompatibles.
			if ( !empty( $idHal ) ) {
				$POST_query['idHal'] = implode( ';', $idHal );
			} elseif ( !empty( $HAL_ids ) ) {
				$POST_query['struct'] = implode( ';', $HAL_ids );
			} else {
				return array( '', '' ); /*Vide*/
			}
		}

		//---------------------------------------------------
		// 7 - contruire l'URL
		//---------------------------------------------------
		$url = '';
		if ( !( '' === $request_mode ) ) {
			$url = $api_base_url.http_build_query ( $POST_query );
		}
		return array( $request_mode, $url );
	}

	//==========================================================================
	/**
	 * Analyseur syntaxique de la page retournée par haltools
	 * @param string $hal_content la page retournée par haltools
	 * @return array le tableau des publications [type][année][ordre][champs]
	 *			   champs : titre, auteur, article
	 */
	//==========================================================================
	static function parse_haltools_response( $hal_content = '' ) {
		$publi =array();
	  /*
		$caractere_texte = array( 'à', 'À', 'á', 'Á', 'â', 'Â', 'ã', 'Ā', 'ä', 'Ä', 'å', 'Å', 'æ', 'Æ',
								 'è', 'È', 'é', 'É', 'ê', 'Ê', 'ë', 'Ë',
								 'ì', 'Ì', 'í', 'Í', 'î', 'Î', 'ï', 'Ï',
								 'ò', 'Ò', 'ó', 'Ó', 'ô', 'Ô', 'õ', 'Õ', 'ö', 'Ö', 'ø', 'Ø',
								 'ù', 'Ù', 'ú', 'Ú', 'û', 'Û', 'ü', 'Ü',
								 'ñ', 'ç', 'Ç', 'ý', 'Ý', 'ß',
								 '°',
								);
		*/
		$caractere_texte = array( '&agrave;', '&Agrave;', '&aacute;', '&Aacute;', '&acirc;', '&Acirc;', '&atilde;', '&Atilde;', '&auml;', '&Auml;', '&aring;', '&Aring;', '&aelig;', '&AElig;',
								 '&egrave;', '&Egrave;', '&eacute;', '&Eacute;', '&ecirc;', '&Ecirc;', '&etilde;', '&Etilde;', '&euml;', '&Euml;',
								 '&igrave;', '&Igrave;', '&iacute;', '&Iacute;', '&icirc;', '&Icirc;', '&itilde;', '&Itilde;', '&iuml;', '&Iuml;',
								 '&ograve;', '&Ograve;', '&oacute;', '&Oacute;', '&ocirc;', '&Ocirc;', '&otilde;', '&Otilde;', '&ouml;', '&Ouml;', '&oslash;', '&Oslash;', '&oelig;', '&OElig;',
								 '&ugrave;', '&Ugrave;', '&uacute;', '&Uacute;', '&ucirc;', '&Ucirc;', '&utilde;', '&Utilde;', '&uuml;', '&Uuml;',
								 '&ntilde;', '&ccedil;', '&Ccedil;', '&yacute;', '&Yacute;', '&szlig;', '&amp;',
								 '&deg;',
								);
		$caractere_latex = array( '{\`a}', '{\`A}', "{\'a}", "{\'A}", '{\^a}', '{\^A}', '{\~a}', '{\~A}', '{\"a}', '{\"A}', '{\aa}', '{\AA}', '{\ae}', '{\AE}',
								 '{\`e}', '{\`E}', "{\'e}", "{\'E}", '{\^e}', '{\^E}', '{\~e}', '{\~E}', '{\"e}', '{\"E}',
								 '{\`i}', '{\`I}', "{\'i}", "{\'I}", '{\^i}', '{\^I}', '{\~i}', '{\~I}', '{\"i}', '{\"I}',
								 '{\`o}', '{\`O}', "{\'o}", "{\'O}", '{\^o}', '{\^O}', '{\~o}', '{\~O}', '{\"o}', '{\"O}', '{\o}', '{\O}', '{\oe}', '{\OE}',
								 '{\`u}', '{\`U}', "{\'u}", "{\'U}", '{\^u}', '{\^U}', '{\~u}', '{\~U}', '{\"u}', '{\"U}',
								 '{\~n}', '{\c c}', '{\c C}', "{\'y}", "{\'Y}", '{\ss}', '\&',
								 '{\textdegree}',
								);
		/*$webservice_class_instance = New $webservice_class_name();
		$hal_content = $webservice_class_instance->webpage_get_content( $url );*/

		$data_contenu = explode ( '@', $hal_content ); //Séparer chaque entrée bibliographique
		foreach ( $data_contenu as $id_publi => $datum_publi ) {
			$datum_publi = str_replace( $caractere_latex, $caractere_texte, $datum_publi );
			if ( 0 != $id_publi ) { //On ne prend que après le premier @
				// correction du probleme de MONTH dans hal
				//On recherche 'MONTH = truc, ' et on le remplace par 'MONTH = {truc}, '
				//Cette recherche se fait indépendament de la case ( /i ) et du nombre de carracères d'espacement ou tabulation autour du =
				$datum_publi = preg_replace( '/MONTH\s*=\s*(\S+)\s*,/i', 'MONTH = {${1}},', $datum_publi );
				//type = mot en début de chaine avant le première accolade. (/s est pour le traitement multiligne)
				$type = preg_replace( '/^([^{]+)\S*{.*/s','${1}',$datum_publi );
				//contenu = tout ce qui est dans les accolades suivantes (les espaces et sauts de lignes autour ne comptent pas)
				$contenu = preg_replace( '/^([^{]+)\S*{\S*(.*)\S*}\S*$/s','${2}', $datum_publi );
				//On récupère un gros tableau des 'field' = 'values', en étant tolérant sur les espaces surnuméraires.
				preg_match_all( '/(?P<field>\w+)[ \t]* = [ \t]*(?P<values>.*)\S*,\S*[\n\r\f]+/', $contenu, $matches );
				$fields = $matches['field'];
				$values = $matches['values'];
				$publi_tmp = array();
				foreach ( $fields as $key => $value ) {
					$publi_tmp [strtoupper( $fields[$key] ) ] = $values[$key];
				}
				//nettoyage de chaque champs
				foreach ( $publi_tmp as $key => $value ) {
					$value = self::suppress_bibtex_value_limiter( $value );
					$publi_tmp[$key] = str_replace( array( '{','}' ), '', $value );
				}
				if ( !empty( $publi_tmp['YEAR'] ) ) {
					$annee = $publi_tmp['YEAR'];
				} else {
					$annee = 'unknown year'; //En cas de fichier bib invalide
				}
				if ( !empty( $publi_tmp['TYPE'] ) ) {
					if ( strcmp( substr( $publi_tmp['TYPE'], 0, 12 ), 'Habilitation' ) === 0 ) {
						$publi['hdr'][$annee][] = $publi_tmp;
					} elseif ( strcmp( $publi_tmp['TYPE'], 'Theses' ) === 0 ) {
						$publi['phdthesis'][$annee][] = $publi_tmp;
					} else {
						$publi[$type][$annee][] = $publi_tmp;
					}
				} else {
					$publi[$type][$annee][] = $publi_tmp;
				}
			}
		}
		return $publi;
	}

	//==========================================================================
	/**
	 * formatage des publications
	 * @param string $publi le tableau des publications[type][année][ordre][champs]
	 * @return string le html à afficher
	 */
	//==========================================================================
	static function format_publi( $format = 'ieee', $data_publi, $currentlang ) {
		//Voir https://doc.archives-ouvertes.fr/bib2hal/champs-bibtex-obligatoiresoptionnels-par-type/
		//Il faudra rajouter:
		//@conference
		//@presconf
		//@poster
		//@inbook
		//@proceedings
		//@manual
		//@note

		$type_name = array(
			'article'	   => array( 'en' => 'Journal articles'						, 'fr' => 'Article dans une revue' ),
			'inproceedings' => array( 'en' => 'Conference papers'					   , 'fr' => 'Communication dans un congrès' ),
			'incollection'  => array( 'en' => 'Book sections'						   , 'fr' => 'Chapitre d\'ouvrage' ),
			'book'		  => array( 'en' => 'Books'								   , 'fr' => 'Ouvrage (y compris édition critique et traduction)' ),
			'hdr'		   => array( 'en' => 'Habilitation à diriger des recherches'   , 'fr' => 'HDR' ),
			'mastersthesis' => array( 'en' => 'Master thesis'						   , 'fr' => 'Mémoire d\'étudiant' ),
			'techreport'	=> array( 'en' => 'Reports'								 , 'fr' => 'Rapport' ),
			'misc'		  => array( 'en' => 'Other publications'					  , 'fr' => 'Autre publication' ),
			//Sont aussi classés dans la categorie bibtex @misc les catégories HAL suivantes :
			//			  - Posters
			//			  - Autre rapport, séminaire, workshop
			//			  - Document associé à des manifestations scientifiques
			//			  - Carte
			'phdthesis'	 => array( 'en' => 'Theses'								  , 'fr' => 'Thèse' ),
			'unpublished'   => array( 'en' => 'Preprints, Working Papers, ...'		  , 'fr' => 'Pré-publication, Document de travail' ),
			//Sont aussi classés dans la categorie bibtex @unpublished les catégories HAL suivantes :
			//			  - Cours
			'patent'		=> array( 'en' => 'Patents'								 , 'fr' => 'Brevet' ), //TODO rajouter le formatage
			'proceedings'   => array( 'en' => 'Directions of work or proceedings'	   , 'fr' => 'Direction d\'ouvrage, Proceedings, Dossier' ), //TODO rajouter le formatage
		);
		switch ( $currentlang ) {
			case 'en-US':
			case 'en-GB':
				$lang = 'en';
				break;

			case 'fr-FR':
			default:
				$lang = 'fr';
				break;
		}

		$a_afficher = '<div id="res_script">';
		if ( !empty( $data_publi ) ) {
			foreach ( $data_publi as $type => $datum_type ) {
				if ( in_array( $type, array_keys( $type_name ) ) ) { //Vérifier qu'on est capable de traiter le $type dans le switch
					$a_afficher .= "<p class='Rubrique'>".$type_name[$type][$lang].'</p>';
					foreach ( $datum_type as $date => $datum_date ) {
						$a_afficher .= "<p class='SousRubrique'>".$date.'</p>';
						foreach ( $datum_date as $ordre => $datum_order ) {
							if ( !empty( $datum_order['AUTHOR'] ) ) { //Ne rien afficher si pas d'auteur
								$a_afficher .= "<dl class='NoticeRes'><dt class='ChampRes'>ref_biblio</dt><dd class='ValeurRes ref_biblio'>";
								switch ( $format ) {
									case 'ieee' :
										$a_afficher .= self::bibtex_to_ieee_authors( $datum_order['AUTHOR'] );
										switch ( $type ) {
											case 'article' :
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= self::format_bib_field( $datum_order, 'JOURNAL', ' <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'VOLUME', ', vol. #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ', no. #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												break;
											case 'inproceedings' : // Communication dans un congrès
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= self::format_bib_field( $datum_order, 'BOOKTITLE', ' in <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'ADDRESS', ', #{field}' );
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												break;
											case 'incollection' : // Chapitre d'ouvrage
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= self::format_bib_field( $datum_order, 'BOOKTITLE', ' in <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'SERIES', ' (#{field})' );
												if ( !empty( $datum_order['ADDRESS'] ) ) {
												  $a_afficher .= ', '.$datum_order['ADDRESS'];
												  $a_afficher .= self::format_bib_field( $datum_order, 'PUBLISHER', ': #{field}' );
												} else {
												  $a_afficher .= self::format_bib_field( $datum_order, 'PUBLISHER', ', #{field}' );
												}
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												break;
											case 'book' : // Ouvrage (y compris édition critique et traduction )
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'SERIES', ' (#{field})' );
												if ( !empty( $datum_order['ADDRESS'] ) ) {
												  $a_afficher .= ', '.$datum_order['ADDRESS'];
												  $a_afficher .= self::format_bib_field( $datum_order, 'PUBLISHER', ': #{field}' );
												} else {
												  $a_afficher .= self::format_bib_field( $datum_order, 'PUBLISHER', ', #{field}' );
												}
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												break;
											case 'hdr' : // HDR
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= ' H.D.R. dissertation';
												$a_afficher .= self::format_bib_field( $datum_order, 'SCHOOL', ', #{field}' );
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												break;
											case 'mastersthesis' : // Mémoire d'étudiant
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= ' student dissertation';
												$a_afficher .= self::format_bib_field( $datum_order, 'SCHOOL', ', #{field}' );
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												break;
											case 'techreport' : // Rapport
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= ' unpublished';
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												break;
											case 'misc' : //Autre publication
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= ' unpublished';
												$a_afficher .= self::format_bib_field( $datum_order, 'HOWPUBLISHED', ', <i>#{field}</i>' );
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												break;
											case 'phdthesis' : // Thèse
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= ' M.S. thesis';
												$a_afficher .= self::format_bib_field( $datum_order, 'SCHOOL', ', #{field}' );
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ', no. #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												break;
											case 'unpublished' : // Pré-publication, Document de travail
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= ' unpublished';
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												break;
											case 'patent' : // brevet
												//http://libraryguides.vu.edu.au/ieeereferencing/standardsandpatents
												//Author(s) Initial(s). Surname(s), “Title of patent,” Published Patent’s country of origin and number xxxx, Abbrev. Month. Day, Year of Publication.​
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= self::format_bib_field( $datum_order, 'ADDRESS', ' #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ' Patent #{field}' );
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												break;
											case 'proceedings' : // Direction d'ouvrage, Proceedings, Dossier
												//http://libraryguides.vu.edu.au/ieeereferencing/confernenceproceedings
												//Author( s) Initial( s). Surname( s), “Title of paper,” in <i>Abbrev. Name of Conf.</i>, [location of conference is optional], [vol., no. if available], Year, pp. xxx–xxx.
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= self::format_bib_field( $datum_order, 'BOOKTITLE', ' in <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'ADDRESS', ', #{field}' );
												$a_afficher .= ', ';
												$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', '#{field}. ' );
												$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'VOLUME', ', vol. #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ', no. #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', pp. #{field}' );
												break;
										}
										$a_afficher .= '.';
										$a_afficher .= self::format_bib_field( $datum_order,  'DOI', ' <a target="_blank" href="http://dx.doi.org/#{field}">&lt;#{field}&gt;</a>.' );
										$a_afficher .= self::format_bib_field( $datum_order, 'HAL_ID-URL', ' #{field}.' );
										$a_afficher .= self::format_bib_field( $datum_order, 'PDF', ' <a href="#{field}" target="_blank"><img style="width:11px; height:11px;" src="http://haltools.archives-ouvertes.fr/images/Haltools_pdf.png" title="#{field}" border="0"></a>' );
										break;

									case 'apa' :
										$a_afficher .= self::bibtex_to_apa_authors( $datum_order['AUTHOR'] );
										$a_afficher .= ' (';
										$a_afficher .= self::format_bib_field( $datum_order, 'YEAR', '#{field}' );
										$a_afficher .= self::format_bib_field( $datum_order, 'MONTH', ', #{field}' );
										$a_afficher .= ').';
										switch ( $type ) {
											case 'article' :
												$a_afficher .= ' ';
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ' #{field}.' );
												$a_afficher .= self::format_bib_field( $datum_order, 'JOURNAL', ' <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'VOLUME', ', #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ' (#{field})' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', #{field}' );
												break;
											case 'inproceedings' : // Communication dans un congrès
												$a_afficher .= ' ';
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ' <i>#{field}</i>.' );
												$a_afficher .= self::format_bib_field( $datum_order, 'BOOKTITLE', ' Paper presented at the #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'ADDRESS', ', #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'VOLUME', ', #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ' (#{field})' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', #{field}' );
												break;
											case 'incollection' : // Chapitre d'ouvrage
												if ( !empty( $datum_order['EDITOR'] ) ) {
													$a_afficher .= ' In '.$datum_order['EDITOR'];
													$a_afficher .= self::format_bib_field( $datum_order, 'BOOKTITLE', ', <i>#{field}</i>' );
												} else {
													$a_afficher .= self::format_bib_field( $datum_order, 'BOOKTITLE', ' <i>#{field}</i>' );
												}
												$a_afficher .= self::format_bib_field( $datum_order, 'BOOKTITLE', ', <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'SERIES', ', #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'VOLUME', ', #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ' (#{field})' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', #{field}' );
												break;
											case 'book' : // Ouvrage (y compris édition critique et traduction)
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ' <i>#{field}</i>' );
												if ( !empty( $datum_order['EDITOR'] ) ) {
												  $a_afficher .= ' In '.$datum_order['EDITOR'];
												  $a_afficher .= self::format_bib_field( $datum_order, 'PUBLISHER', ', #{field}' );
												} else {
												  $a_afficher .= self::format_bib_field( $datum_order, 'PUBLISHER', ' #{field}' );
												}
												$a_afficher .= self::format_bib_field( $datum_order, 'BOOKTITLE', ', <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'SERIES', ', #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'VOLUME', ', #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ' (#{field})' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', #{field}' );
												break;
											case 'hdr' : // HDR
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ' <i>#{field}</i>' );
												if ( empty( $datum_order['PDF'] ) ) {
													$a_afficher .= ', HDR not published ';
													$a_afficher .= self::format_bib_field( $datum_order, 'SCHOOL', ', HDR not published #{field}' );
												} else {
													$a_afficher .= self::format_bib_field( $datum_order, 'SCHOOL', ', HDR (#{field})' );
												}
												break;
											case 'mastersthesis' : // Mémoire d'étudiant
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ' <i>#{field}</i>' );
												if ( empty( $datum_order['PDF'] ) ) {
													$a_afficher .= ', HDR not published ';
													$a_afficher .= self::format_bib_field( $datum_order, 'SCHOOL', ', HDR not published #{field}' );
												} else {
													$a_afficher .= self::format_bib_field( $datum_order, 'SCHOOL', ', HDR (#{field})' );
												}
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', #{field}' );
												break;
											case 'techreport' : // Rapport
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ' <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ' (#{field})' );
												$a_afficher .= self::format_bib_field( $datum_order, 'INSTITUTION', ', #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', #{field}' );
												break;
											case 'misc' : // Autre publication
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ' <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'HOWPUBLISHED', ', Paper presented at the #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', #{field}' );
												break;
											case 'phdthesis' : // Thèse
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ' <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ' (#{field})' );
												if (empty( $datum_order['PDF'] ) ) {
													$a_afficher .= ', Thesis not published ';
													$a_afficher .= self::format_bib_field( $datum_order, 'SCHOOL', ', Thesis not published #{field}' );
												} else {
													$a_afficher .= self::format_bib_field( $datum_order, 'SCHOOL', ', Thesis (#{field})' );
												}
												break;
											case 'unpublished' : // Pré-publication, Document de travail
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ' <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ', #{field}' );
												break;
											case 'patent' : // brevet
												//http://libraryguides.vu.edu.au/apa-referencing/patents-and-standards
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ' <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'NUMBER', ' <i>No. #{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'ADDRESS', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PUBLISHER', ': #{field}' );
												break;
											case 'proceedings' : // Direction d'ouvrage, Proceedings, Dossier
												//http://libraryguides.vu.edu.au/apa-referencing/conference-proceedings
												$a_afficher .= self::format_bib_field( $datum_order, 'TITLE', ', "#{field},"' );
												$a_afficher .= self::format_bib_field( $datum_order, 'EDITOR', ', #{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'BOOKTITLE', ', <i>#{field}</i>' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PAGES', ' (pp. #{field})' );
												$a_afficher .= '. ';
												$a_afficher .= self::format_bib_field( $datum_order, 'ADDRESS', '#{field}' );
												$a_afficher .= self::format_bib_field( $datum_order, 'PUBLISHER', ': #{field}' );
												break;
										}
										$a_afficher .= '.';
										$a_afficher .= self::format_bib_field( $datum_order,  'DOI', ' <a target="_blank" href="http://dx.doi.org/#{field}">&lt;#{field}&gt;</a>.' );
										$a_afficher .= self::format_bib_field( $datum_order, 'HAL_ID-URL', ' #{field}.' );
										$a_afficher .= self::format_bib_field( $datum_order, 'PDF', ' <a href="#{field}" target="_blank"><img style="width:11px; height:11px;" src="http://haltools.archives-ouvertes.fr/images/Haltools_pdf.png" title="#{field}" border="0"></a>' );
										break;
								}
								$a_afficher .= '</dd></dl>';
							}
						}
					}
				}
			}
		}
		$a_afficher .= '</div>';
		return $a_afficher;
	}

	//==========================================================================
	/**
	 * formatage des auteurs au format IEEE à partir des auteurs BibTex
	 * @param string $authors_bib_string auteurs au format BibTex
	 * @return string auteurs au format IEEE
	 */
	//==========================================================================
	static function bibtex_to_ieee_authors( $authors_bib_string ) {
		$authors = explode( ' and ', $authors_bib_string );
		$authors_names = array();
		foreach ( $authors as $author ) {
			$names = explode( ',', $author );
			$first_names = explode( ' ', trim( $names[1] ) );
			$abreviated_first_names = array();
			foreach ( $first_names as $first_name_datum ) {
				$composed_first_names = explode( '-', $first_name_datum );
				if ( count( $composed_first_names ) > 1 ) {
					$abreviated_composed_first_names = array();
					foreach ( $composed_first_names as $composed_first_name ) {
						$abreviated_composed_first_names[] = strtoupper( substr( trim( $composed_first_name ), 0, 1 ) ).'.';
					}
					$abreviated_first_names[] = implode( '-', $abreviated_composed_first_names );
				} else {
					$abreviated_first_names[] = strtoupper( substr( trim( $composed_first_names[0] ), 0, 1 ) ).'.';
				}
			}
			$last_names = explode( ' ', trim( $names[0] ) );
			$cased_last_names = array();
			foreach ( $last_names as $last_name_datum ) {
				$composed_last_names = explode( '-', $last_name_datum );
				if ( count( $composed_last_names ) > 1 ) {
					$cased_composed_last_names = array();
					foreach ( $composed_last_names as $composed_last_name ) {
						$cased_composed_last_names[] = ucwords( strtolower( trim( $composed_last_name ) ) );
					}
					$cased_last_names[] = implode( '-', $cased_composed_last_names );
				} else {
					$cased_last_names[] = ucwords( strtolower( trim( $composed_last_names[0] ) ) );
				}
			}
			$first_name = implode( ' ', $abreviated_first_names );
			$last_name = implode( ' ', $cased_last_names );
			$authors_names[] = $first_name.' '.$last_name;
		}
		if ( count( $authors ) > 1 ) {
			$authors_name = implode( array_splice( $authors_names, 0, count( $authors_names )-1 ), ', ' );
			if ( !empty( $authors_names ) ) {
				$authors_name .= ', and '.$authors_names[0];
			}
		} else {
			$authors_name = $authors_names[0];
		}
		return $authors_name;
	}

	//==========================================================================
	/**
	 * formatage des auteurs au format APA à partir des auteurs BibTex
	 * @param string $authors_bib_string auteurs au format BibTex
	 * @return string auteurs au format APA
	 */
	//==========================================================================
	static function bibtex_to_apa_authors( $authors_bib_string ) {
		$authors = explode( ' and ', $authors_bib_string );
		$authors_names = array();
		foreach ( $authors as $author ) {
			$names = explode( ',', $author );
			$first_names = explode( ' ', trim( $names[1] ) );
			$abreviated_first_names = array();
			foreach ( $first_names as $first_name_datum ) {
				$composed_first_names = explode( '-', $first_name_datum );
				if ( count( $composed_first_names ) > 1 ) {
					$abreviated_composed_first_names = array();
					foreach ( $composed_first_names as $composed_first_name ) {
						$abreviated_composed_first_names[] = strtoupper( substr( trim( $composed_first_name ), 0, 1 ) ).'.';
					}
					$abreviated_first_names[] = implode( '-', $abreviated_composed_first_names );
				} else {
					$abreviated_first_names[] = strtoupper( substr( trim( $composed_first_names[0] ), 0, 1 ) ).'.';
				}
			}
			$first_name = implode( '', $abreviated_first_names );
			$last_name = ucwords( strtolower( trim( $names[0] ) ) );
			$authors_names[] = $last_name.', '.$first_name;
		}
		if ( count( $authors ) > 1 ) {
			$authors_name = implode( array_splice( $authors_names, 0, count( $authors_names )-1 ), ', ' );
			if ( !empty( $authors_names ) ) {
				$authors_name .= ', & '.$authors_names[0];
			}
		} else {
			$authors_name = $authors_names[0];
		}
		return $authors_name;
	}

	//==========================================================================
	/**
	 * formatage des champs issus d'un fichier BibTex
	 * @param array $array tableau où récupérer le champs BibTex
	 * @param string $field index du champs du tableau à récupérer
	 * @param string $format formatage à produire à partir du champs
	 * @return string code HTML généré
	 */
	//==========================================================================
	static function format_bib_field( $array, $field, $format ) {
		$a_afficher = '';
		$field = strtoupper( $field );
		//Pre-preprocess:
		//-----------
		if ( 'HAL_ID-URL' === $field ) {
			if ( !empty( $array['HAL_ID'] ) and !empty( $array['URL'] ) ) {
				//lien de HAL_ID avec URL
				$field = 'HAL_ID';
				$format = str_replace( '#{field}', '<a target="_blank" href="'.$array['URL'].'">&lt;#{field}&gt;</a>', $format );
			} elseif ( !empty( $array['HAL_ID'] ) and  empty( $array['URL'] ) ) {
				//lien de HAL_ID avec HAL_ID
				$field = 'HAL_ID';
				$format = str_replace( '#{field}', '<a target="_blank" href="https://hal.archives-ouvertes.fr/'.$array['HAL_ID'].'">&lt;#{field}&gt;</a>', $format );
			} elseif ( empty( $array['HAL_ID'] ) and !empty( $array['URL'] ) ) {
				//lien URL simple
				$field = 'URL';
				$format = str_replace( '#{field}', '<a target="_blank" href="'.$array['URL'].'">#{field}</a>', $format );
			} else {
				//ne rien afficher
				$field = 'INVALID';
			}
		}

		if ( !empty( $array[$field] ) ) {

			//Preprocess:
			//-----------
			switch ( $field ) {
				case 'PAGES':
				$reprocessed = trim( str_replace( 'p', '', str_replace( 'p.', '', str_replace( 'pp', '', str_replace( 'pp.', '', $array[$field] ) ) ) ) );
				break;

				case 'MONTH':
				$reprocessed = substr( $array[$field], 0, 3 );
				break;

				default:
				$reprocessed = $array[$field];
				break;
			}

			//Process:
			//-------
			$a_afficher .= str_replace( '#{field}', $reprocessed, $format );
		}
		return $a_afficher;
	}
}


/**
 * Class MonLabo_contact_webservices
 *
 * @package
 */
class MonLabo_contact_webservices {
	//==========================================================================
	/**
	 * Récupère le contenur d'une URL
	 * @param string $url URL du contenu à récupérer
	 * @return string contenu de la page à l'adresse $url
	 */
	//==========================================================================
	function webpage_get_content( $url ) {
		$contenu = wp_remote_get( $url );
		if ( array_key_exists( "body", $contenu ) ) {
			return $contenu['body'];
		} else {
			return "";
		}
	}
}
?>
