<?php
defined( 'ABSPATH' ) or die( 'No direct script access allowed' );

///////////////////////////////////////////////////////////////////////////////////////////
// Librairie de fonctions pour manipuler les traductions de texte et leur personalisation
///////////////////////////////////////////////////////////////////////////////////////////
/**
 * Class MonLabo_translate
 *
 * @package
 */

/*
	get_customizable_text( $custom_text_tag, $language = '' )
	translate( $sentence_to_translate, $language = '' )
*/

class MonLabo_translate {

	//--------------------------------------------------------------------------------
	// Get the text value of a customizable text
	//--------------------------------------------------------------------------------
	// $custom_text_tag   => tag of custom text ( see all tags in part MonLabo_settings_group5 in constants.php. Remove '_fr' or '_en' )
	// $language => language to display
	//--------------------------------------------------------------------------------
	public static function get_customizable_text( $custom_text_tag, $language = '' ) {
		$options_DEFAULT = get_options_DEFAULT();

		//Step 1 : identify $language
		//---------------------------
		if ( '' === $language ) {
			$language = get_bloginfo( 'language' );
		}
		switch ( $language ) {
			case 'en':
			case 'en-GB':
			case 'en-US': $suffix = 'en'; break;
			default:	  $suffix = 'fr'; break;
		}

		//Step 2 : return custom text if defined
		$custom_text_defined = false;
		$options0 = get_option( 'MonLabo_settings_group0' );
		if ( isset( $options0['MonLabo_uses_custom_texts_in_shortcodes'] ) && ( intval( $options0['MonLabo_uses_custom_texts_in_shortcodes'] ) === 1 ) ) {
			$options5 = get_option( 'MonLabo_settings_group5' );
			if ( array_key_exists( $custom_text_tag.'_'.$suffix, $options5 ) ) {
				return $options5[$custom_text_tag.'_'.$suffix];
			}
		}

		//Step 3 : return default custom text if defined
		if ( array_key_exists( $custom_text_tag.'_'.$suffix, $options_DEFAULT['MonLabo_settings_group5'] ) ) {
			return $options_DEFAULT['MonLabo_settings_group5'][$custom_text_tag.'_'.$suffix];
		} else {
			return '';
		}
	}


	public static function translate( $sentence_to_translate, $language = '' ) {
		$translation_table = array(
			'Room' => array( 'en-US'=> 'room',
							'fr-FR'=> 'bureau' ),
			'Nom' => array( 'en-US'=> 'Name',
							'fr-FR'=> 'Nom' ),
			'Equipe' => array(  'en-US'=> 'Group',
								'fr-FR'=> 'Équipe' ),
			'Poste' => array(   'en-US'=> 'Position',
								'fr-FR'=> 'Poste' ),
			'Email' => array( 'en-US'=> 'Email',
							'fr-FR'=> 'Courriel' ),
			'Alumni since' => array( 'en-US'=> 'Alumni since',
							  'fr-FR'=> 'Ancien membre depuis' ),
			'Alumni'	   => array( 'en-US'=> 'Alumni',
							'fr-FR'=> 'Ancien membre' ),
			'Former'	   => array( 'en-US'=> 'Former',
							'fr-FR'=> 'Ancienne fonction&nbsp;:' ),
			'Until'	   => array( 'en-US'=> 'Until',
							'fr-FR'=> 'Jusqu\'en' ),
			'Thematic'	   => array( 'en-US'=> 'Thematic',
							'fr-FR'=> 'Thématique' ),
			'Thematics'	   => array( 'en-US'=> 'Thematics',
							'fr-FR'=> 'Thématiques' ),
			'Supervised student'  => array( 'en-US'=> 'Student',
							  'fr-FR'=> 'Étudiant' ),
			'Supervised students' => array( 'en-US'=> 'Students',
								'fr-FR'=> 'Étudiants' ),
			'Supervisor'	   => array( 'en-US'=> 'Supervisor',
							'fr-FR'=> 'Superviseur' ),
			'Supervisors'	   => array( 'en-US'=> 'Supervisors',
							'fr-FR'=> 'Superviseurs' ),
			'Statut'	   => array( 'en-US'=> 'Status',
							'fr-FR'=> 'Statut' ),
			);
		if ( '' === $language ) {
			$language = get_bloginfo( 'language' );
		}
		switch ( $language ) {
			case 'en-GB':
			case 'en':
			case 'en_GB':
			case 'en-US':
			case 'en_US':
				$language = 'en-US';
				break;

			case 'fr':
			case 'fr_FR':
			case 'fr-FR':
				$language = 'fr-FR';
				break;

			default:
				return $sentence_to_translate;
		}
		//Test if first char is lowercase
		$is_first_char_is_uppercase = ctype_upper( substr( $sentence_to_translate, 0, 1 ) );
		if ( array_key_exists( ucfirst( $sentence_to_translate ), $translation_table ) ) {
			if ( $is_first_char_is_uppercase ) {
				return ucfirst( $translation_table[ucfirst( $sentence_to_translate )][$language] );
			} else {
				return lcfirst( $translation_table[ucfirst( $sentence_to_translate )][$language] );
			}
		} else {
			$custom_text = MonLabo_translate::get_customizable_text( 'MonLabo_custom_text_'.str_replace( ' ', '_', ucfirst( $sentence_to_translate ) ), $language );
			if ( !empty( $custom_text ) ) {
				if ( $is_first_char_is_uppercase ) {
					return ucfirst( $custom_text );
				} else {
					return lcfirst( $custom_text );
				}
			} else {
				return $sentence_to_translate;
			}
		}
	}
}
